/*!
* Copyright Adaptavist 2022 (c) All rights reserved
*/
import { getHeaders, UnexpectedError } from "@managed-api/commons-core";
export function constructHeaders(body, manualHeaders, customParams) {
    const additionalHeaders = checkCustomParams(manualHeaders, customParams);
    return getHeaders(body, additionalHeaders);
}
function checkCustomParams(headers, customParams) {
    const newHeaders = { ...headers };
    if (customParams && customParams.preferredAuth) {
        const preferredAuth = customParams.preferredAuth;
        if (preferredAuth !== 'USER' && preferredAuth !== 'BOT') {
            throw new UnexpectedError(undefined, 'Preferred auth can only contain following values: USER, BOT');
        }
        newHeaders['X-SLACK-PREFERRED-AUTH'] = preferredAuth;
    }
    if (customParams && customParams.userId) {
        const userId = customParams.userId;
        newHeaders['X-SLACK-AUTH-USERID'] = userId;
    }
    if (customParams && customParams.responseUrl) {
        const reponseUrl = customParams.responseUrl;
        newHeaders['Slack-Response-Url'] = reponseUrl;
    }
    return newHeaders;
}
export async function errorMessageBuilder(response, reason) {
    return reason;
}
export class SlackError extends Error {
    constructor(response, message) {
        super(message);
        this.response = response;
        this.name = 'SlackError';
    }
}
//# sourceMappingURL=common.js.map