/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { BaseApiCore, constructUrl, executeHttpCall, Request, Response } from "@managed-api/commons-core";
import { constructHeaders, errorMessageBuilder } from "./common";
import { customErrorHandlers, errorStrategyBuilderConstructor } from "./errorStrategy";
export class SlackApiCore extends BaseApiCore {
    constructor(options) {
        var _a, _b;
        super();
        this.options = options;
        if (!((_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy) && ((_b = this.options) === null || _b === void 0 ? void 0 : _b.errorStrategy) !== null) {
            this.setGlobalErrorStrategy((builder) => builder.retryOnRateLimiting(-1));
        }
        this.Admin = new AdminGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.View = new ViewGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.User = new UserGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Reminders = new RemindersGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Pins = new PinsGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Bot = new BotGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Chat = new ChatGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Conversation = new ConversationGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Dialog = new DialogGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Dnd = new DndGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Emoji = new EmojiGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.File = new FileGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Reaction = new ReactionGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Search = new SearchGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Team = new TeamGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.UserGroup = new UserGroupGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Reply = new ReplyGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.All = new AllGroup(this.Admin, this.View, this.User, this.Reminders, this.Pins, this.Bot, this.Chat, this.Conversation, this.Dialog, this.Dnd, this.Emoji, this.File, this.Reaction, this.Search, this.Team, this.UserGroup, this.Reply);
        this.AllUser = new AllUserGroup(this.Admin, this.View, this.User, this.Reminders, this.Pins, this.Bot, this.Chat, this.Conversation, this.Dialog, this.Dnd, this.Emoji, this.File, this.Reaction, this.Search, this.Team, this.UserGroup);
        this.AllBot = new AllBotGroup(this.View, this.User, this.Pins, this.Bot, this.Chat, this.Conversation, this.Dialog, this.Dnd, this.Emoji, this.File, this.Reaction, this.Team, this.UserGroup);
    }
    setGlobalErrorStrategy(errorStrategy) {
        var _a;
        this.options = {
            ...((_a = this.options) !== null && _a !== void 0 ? _a : {}),
            errorStrategy,
        };
    }
    buildResponse(url, status, statusText, headers, body) {
        const response = new Response(url, status, statusText, headers, body);
        response.setBufferImplementation(this.implementation);
        return response;
    }
    getGlobalErrorStrategy() {
        var _a;
        return (_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy;
    }
}
class AllGroup {
    constructor(Admin, View, User, Reminders, Pins, Bot, Chat, Conversation, Dialog, Dnd, Emoji, File, Reaction, Search, Team, UserGroup, Reply) {
        this.Admin = Admin;
        this.View = View;
        this.User = User;
        this.Reminders = Reminders;
        this.Pins = Pins;
        this.Bot = Bot;
        this.Chat = Chat;
        this.Conversation = Conversation;
        this.Dialog = Dialog;
        this.Dnd = Dnd;
        this.Emoji = Emoji;
        this.File = File;
        this.Reaction = Reaction;
        this.Search = Search;
        this.Team = Team;
        this.UserGroup = UserGroup;
        this.Reply = Reply;
    }
    /**
     * Set an existing guest user, admin user, or owner to be a regular user.
     * Alternative usage: Admin.Users.setRegular
     * Documentation: https://api.slack.com/methods/admin.users.setRegular
     * @param options Request options.
     */
    async adminSetRegularUser(options) {
        return this.Admin.Users.setRegular(options);
    }
    /**
     * Set an existing guest, regular user, or admin user to be a workspace owner.
     * Alternative usage: Admin.Users.setOwner
     * Documentation: https://api.slack.com/methods/admin.users.setOwner
     * @param options Request options.
     */
    async adminSetOwnerUser(options) {
        return this.Admin.Users.setOwner(options);
    }
    /**
     * Set an expiration for a guest user
     * Alternative usage: Admin.Users.setExpiration
     * Documentation: https://api.slack.com/methods/admin.users.setExpiration
     * @param options Request options.
     */
    async adminSetUserExpiration(options) {
        return this.Admin.Users.setExpiration(options);
    }
    /**
     * Set an existing guest, regular user, or owner to be an admin user.
     * Alternative usage: Admin.Users.setAdmin
     * Documentation: https://api.slack.com/methods/admin.users.setAdmin
     * @param options Request options.
     */
    async adminSetAdminUser(options) {
        return this.Admin.Users.setAdmin(options);
    }
    /**
     * Remove a user from a workspace.
     * Alternative usage: Admin.Users.removeUser
     * Documentation: https://api.slack.com/methods/admin.users.remove
     * @param options Request options.
     */
    async adminRemoveUser(options) {
        return this.Admin.Users.removeUser(options);
    }
    /**
     * List users on a workspace
     * Alternative usage: Admin.Users.getUsers
     * Documentation: https://api.slack.com/methods/admin.users.list
     * @param options Request options.
     */
    async adminGetUsers(options) {
        return this.Admin.Users.getUsers(options);
    }
    /**
     * Invite a user to a workspace.
     * Recommended usage: Admin.Users.inviteUser
     * Documentation: https://api.slack.com/methods/admin.users.invite
     * @param options Request options.
     */
    async adminInviteUser(options) {
        return this.Admin.Users.inviteUser(options);
    }
    /**
     * Add an Enterprise user to a workspace.
     * Recommended usage: Admin.Users.assignUser
     * Documentation: https://api.slack.com/methods/admin.users.assign
     * @param options Request options.
     */
    async adminAssignUser(options) {
        return this.Admin.Users.assignUser(options);
    }
    /**
     * Update an existing view.
     * Alternative usage: View.updateView
     * Documentation: https://api.slack.com/methods/views.update
     * @param options Request options.
     */
    async updateView(options) {
        return this.View.updateView(options);
    }
    /**
     * Push a view onto the stack of a root view.
     * Alternative usage: View.pushView
     * Documentation: https://api.slack.com/methods/views.push
     * @param options Request options.
     */
    async pushView(options) {
        return this.View.pushView(options);
    }
    /**
     * Publish a static view for a User.
     * Alternative usage: View.publishView
     * Documentation: https://api.slack.com/methods/views.publish
     * @param options Request options.
     */
    async publishView(options) {
        return this.View.publishView(options);
    }
    /**
     * Open a view for a user.
     * Alternative usage: View.openView
     * Documentation: https://api.slack.com/methods/views.open
     * @param options Request options.
     */
    async openView(options) {
        return this.View.openView(options);
    }
    /**
     * Find a user with an email address.
     * Alternative usage: User.getUserByEmail
     * Documentation: https://api.slack.com/methods/users.lookupByEmail
     * @param options Request options.
     */
    async getUserByEmail(options) {
        return this.User.getUserByEmail(options);
    }
    /**
     * Lists all users in a Slack team.
     * Alternative usage: User.getUsers
     * Documentation: https://api.slack.com/methods/users.list
     * @param options Request options.
     */
    async getUsers(options) {
        return this.User.getUsers(options);
    }
    /**
     * Gets information about a user.
     * Alternative usage: User.getInfo
     * Documentation: https://api.slack.com/methods/users.info
     * @param options Request options.
     */
    async getUserInfo(options) {
        return this.User.getInfo(options);
    }
    /**
     * Get a user's identity.
     * Alternative usage: User.getIdentity
     * Documentation: https://api.slack.com/methods/users.identity
     * @param options Request options.
     */
    async getUserIdentity(options) {
        return this.User.getIdentity(options);
    }
    /**
     * List conversations the calling user may access.
     * Alternative usage: User.getConversations
     * Documentation: https://api.slack.com/methods/users.conversations
     * @param options Request options.
     */
    async getUserConversations(options) {
        return this.User.getConversations(options);
    }
    /**
     * Gets user presence information.
     * Alternative usage: User.getPresence
     * Documentation: https://api.slack.com/methods/users.getPresence
     * @param options Request options.
     */
    async getUserPresence(options) {
        return this.User.getPresence(options);
    }
    /**
     * Manually sets user presence.
     * Alternative usage: User.setPresence
     * Documentation: https://api.slack.com/methods/users.setPresence
     * @param options Request options.
     */
    async setUserPresence(options) {
        return this.User.setPresence(options);
    }
    /**
     * Set the profile information for a user.
     * Alternative usage: User.Profile.setProfile
     * Documentation: https://api.slack.com/methods/users.profile.set
     * @param options Request options.
     */
    async setUserProfile(options) {
        return this.User.Profile.setProfile(options);
    }
    /**
     * Retrieves a user's profile information.
     * Alternative usage: User.Profile.getProfile
     * Documentation: https://api.slack.com/methods/users.profile.get
     * @param options Request options.
     */
    async getUserProfile(options) {
        return this.User.Profile.getProfile(options);
    }
    /**
     * Lists all reminders created by or for a given user.
     * Alternative usage: Reminders.getReminders
     * Documentation: https://api.slack.com/methods/reminders.list
     * @param options Request options.
     */
    async getReminders(options) {
        return this.Reminders.getReminders(options);
    }
    /**
     * Gets information about a reminder.
     * Alternative usage: Reminders.getInfo
     * Documentation: https://api.slack.com/methods/reminders.info
     * @param options Request options.
     */
    async getReminderInfo(options) {
        return this.Reminders.getInfo(options);
    }
    /**
     * Deletes a reminder.
     * Alternative usage: Reminders.deleteReminder
     * Documentation: https://api.slack.com/methods/reminders.delete
     * @param options Request options.
     */
    async deleteReminder(options) {
        return this.Reminders.deleteReminder(options);
    }
    /**
     * Marks a reminder as complete.
     * Alternative usage: Reminders.completeReminder
     * Documentation: https://api.slack.com/methods/reminders.complete
     * @param options Request options.
     */
    async completeReminder(options) {
        return this.Reminders.completeReminder(options);
    }
    /**
     * Creates a reminder.
     * Alternative usage: Reminders.addReminder
     * Documentation: https://api.slack.com/methods/reminders.add
     * @param options Request options.
     */
    async addReminder(options) {
        return this.Reminders.addReminder(options);
    }
    /**
     * Un-pins an item from a channel.
     * Alternative usage: Pins.removePin
     * Documentation: https://api.slack.com/methods/pins.remove
     * @param options Request options.
     */
    async removePin(options) {
        return this.Pins.removePin(options);
    }
    /**
     * Lists items pinned to a channel.
     * Alternative usage: Pins.getPins
     * Documentation: https://api.slack.com/methods/pins.list
     * @param options Request options.
     */
    async getPins(options) {
        return this.Pins.getPins(options);
    }
    /**
     * Pins an item to a channel.
     * Alternative usage: Pins.addPin
     * Documentation: https://api.slack.com/methods/pins.add
     * @param options Request options.
     */
    async addPin(options) {
        return this.Pins.addPin(options);
    }
    /**
     * Gets information about a bot user.
     * Alternative usage: Bot.getInfo
     * Documentation: https://api.slack.com/methods/bots.info
     * @param options Request options.
     */
    async getBotInfo(options) {
        return this.Bot.getInfo(options);
    }
    /**
     * Deletes a message.
     * Alternative usage: Chat.deleteMessage
     * Documentation: https://api.slack.com/methods/chat.delete
     * @param options Request options.
     */
    async deleteChatMessage(options) {
        return this.Chat.deleteMessage(options);
    }
    /**
     * Deletes a pending scheduled message from the queue.
     * Alternative usage: Chat.deleteScheduledMessage
     * Documentation: https://api.slack.com/methods/chat.deleteScheduledMessage
     * @param options Request options.
     */
    async deleteChatScheduledMessage(options) {
        return this.Chat.deleteScheduledMessage(options);
    }
    /**
     * Retrieve a permalink URL for a specific extant message
     * Alternative usage: Chat.getPermalink
     * Documentation: https://api.slack.com/methods/chat.getPermalink
     * @param options Request options.
     */
    async getChatPermalink(options) {
        return this.Chat.getPermalink(options);
    }
    /**
     * Share a me message into a channel.
     * Alternative usage: Chat.postMeMessage
     * Documentation: https://api.slack.com/methods/chat.meMessage
     * @param options Request options.
     */
    async postChatMeMessage(options) {
        return this.Chat.postMeMessage(options);
    }
    /**
     * Sends an ephemeral message to a user in a channel.
     * Alternative usage: Chat.postEphemeralMessage
     * Documentation: https://api.slack.com/methods/chat.postEphemeral
     * @param options Request options.
     */
    async postChatEphemeralMessage(options) {
        return this.Chat.postEphemeralMessage(options);
    }
    /**
     * Sends a message to a channel.
     * Alternative usage: Chat.postMessage
     * Documentation: https://api.slack.com/methods/chat.postMessage
     * @param options Request options.
     */
    async postChatMessage(options) {
        return this.Chat.postMessage(options);
    }
    /**
     * Schedules a message to be sent to a channel.
     * Alternative usage: Chat.scheduleMessage
     * Documentation: https://api.slack.com/methods/chat.scheduleMessage
     * @param options Request options.
     */
    async scheduleChatMessage(options) {
        return this.Chat.scheduleMessage(options);
    }
    /**
     * Returns a list of scheduled messages.
     * Alternative usage: Chat.getScheduledMessages
     * Documentation: https://api.slack.com/methods/chat.scheduledMessages.list
     * @param options Request options.
     */
    async getChatScheduledMessages(options) {
        return this.Chat.getScheduledMessages(options);
    }
    /**
     * Provide custom unfurl behavior for user-posted URLs
     * Alternative usage: Chat.unfurlMessage
     * Documentation: https://api.slack.com/methods/chat.unfurl
     * @param options Request options.
     */
    async unfurlChatMessage(options) {
        return this.Chat.unfurlMessage(options);
    }
    /**
     * Updates a message.
     * Alternative usage: Chat.updateMessage
     * Documentation: https://api.slack.com/methods/chat.update
     * @param options Request options.
     */
    async updateChatMessage(options) {
        return this.Chat.updateMessage(options);
    }
    /**
     * Archives a conversation.
     * Alternative usage: Conversation.archiveConversation
     * Documentation: https://api.slack.com/methods/conversations.archive
     * @param options Request options.
     */
    async archiveConversation(options) {
        return this.Conversation.archiveConversation(options);
    }
    /**
     * Closes a direct message or multi-person direct message.
     * Alternative usage: Conversation.closeConversation
     * Documentation: https://api.slack.com/methods/conversations.close
     * @param options Request options.
     */
    async closeConversation(options) {
        return this.Conversation.closeConversation(options);
    }
    /**
     * Initiates a public or private channel-based conversation
     * Alternative usage: Conversation.createConversation
     * Documentation: https://api.slack.com/methods/conversations.create
     * @param options Request options.
     */
    async createConversation(options) {
        return this.Conversation.createConversation(options);
    }
    /**
     * Fetches a conversation's history of messages and events.
     * Alternative usage: Conversation.getHistory
     * Documentation: https://api.slack.com/methods/conversations.history
     * @param options Request options.
     */
    async getConversationHistory(options) {
        return this.Conversation.getHistory(options);
    }
    /**
     * Retrieve information about a conversation.
     * Alternative usage: Conversation.getInfo
     * Documentation: https://api.slack.com/methods/conversations.info
     * @param options Request options.
     */
    async getConversationInfo(options) {
        return this.Conversation.getInfo(options);
    }
    /**
     * Invites users to a channel.
     * Alternative usage: Conversation.inviteUser
     * Documentation: https://api.slack.com/methods/conversations.invite
     * @param options Request options.
     */
    async inviteUserToConversation(options) {
        return this.Conversation.inviteUser(options);
    }
    /**
     * Joins an existing conversation.
     * Alternative usage: Conversation.joinConversation
     * Documentation: https://api.slack.com/methods/conversations.join
     * @param options Request options.
     */
    async joinConversation(options) {
        return this.Conversation.joinConversation(options);
    }
    /**
     * Removes a user from a conversation.
     * Alternative usage: Conversation.kickUser
     * Documentation: https://api.slack.com/methods/conversations.kick
     * @param options Request options.
     */
    async kickUserFromConversation(options) {
        return this.Conversation.kickUser(options);
    }
    /**
     * Leaves a conversation.
     * Alternative usage: Conversation.leaveConversation
     * Documentation: https://api.slack.com/methods/conversations.leave
     * @param options Request options.
     */
    async leaveConversation(options) {
        return this.Conversation.leaveConversation(options);
    }
    /**
     * Lists all channels in a Slack team.
     * Recommended usage: Conversation.getConversations
     * Documentation: https://api.slack.com/methods/conversations.list
     * @param options Request options.
     */
    async getConversations(options) {
        return this.Conversation.getConversations(options);
    }
    /**
     * Retrieve members of a conversation.
     * Alternative usage: Conversation.getMembers
     * Documentation: https://api.slack.com/methods/conversations.members
     * @param options Request options.
     */
    async getConversationMembers(options) {
        return this.Conversation.getMembers(options);
    }
    /**
     * Opens or resumes a direct message or multi-person direct message.
     * Alternative usage: Conversation.openConversation
     * Documentation: https://api.slack.com/methods/conversations.open
     * @param options Request options.
     */
    async openConversation(options) {
        return this.Conversation.openConversation(options);
    }
    /**
     * Renames a conversation.
     * Alternative usage: Conversation.renameConversation
     * Documentation: https://api.slack.com/methods/conversations.rename
     * @param options Request options.
     */
    async renameConversation(options) {
        return this.Conversation.renameConversation(options);
    }
    /**
     * Retrieve a thread of messages posted to a conversation
     * Alternative usage: Conversation.getReplies
     * Documentation: https://api.slack.com/methods/conversations.replies
     * @param options Request options.
     */
    async getConversationReplies(options) {
        return this.Conversation.getReplies(options);
    }
    /**
     * Sets the purpose for a conversation.
     * Alternative usage: Conversation.setPurpose
     * Documentation: https://api.slack.com/methods/conversations.setPurpose
     * @param options Request options.
     */
    async setConversationPurpose(options) {
        return this.Conversation.setPurpose(options);
    }
    /**
     * Sets the topic for a conversation.
     * Alternative usage: Conversation.setTopic
     * Documentation: https://api.slack.com/methods/conversations.setTopic
     * @param options Request options.
     */
    async setConversationTopic(options) {
        return this.Conversation.setTopic(options);
    }
    /**
     * Reverses conversation archival.
     * Alternative usage: Conversation.unarchiveConversation
     * Documentation: https://api.slack.com/methods/conversations.unarchive
     * @param options Request options.
     */
    async unarchiveConversation(options) {
        return this.Conversation.unarchiveConversation(options);
    }
    /**
     * Open a dialog with a user
     * Alternative usage: Dialog.openDialog
     * Documentation: https://api.slack.com/methods/dialog.open
     * @param options Request options.
     */
    async openDialog(options) {
        return this.Dialog.openDialog(options);
    }
    /**
     * Ends the current user's Do Not Disturb session immediately.
     * Alternative usage: Dnd.endDnd
     * Documentation: https://api.slack.com/methods/dnd.endDnd
     * @param options Request options.
     */
    async endDnd(options) {
        return this.Dnd.endDnd(options);
    }
    /**
     * Ends the current user's snooze mode immediately.
     * Alternative usage: Dnd.endSnooze
     * Documentation: https://api.slack.com/methods/dnd.endSnooze
     * @param options Request options.
     */
    async endDndSnooze(options) {
        return this.Dnd.endSnooze(options);
    }
    /**
     * Retrieves a user's current Do Not Disturb status.
     * Alternative usage: Dnd.getInfo
     * Documentation: https://api.slack.com/methods/dnd.info
     * @param options Request options.
     */
    async getDndInfo(options) {
        return this.Dnd.getInfo(options);
    }
    /**
     * Turns on Do Not Disturb mode for the current user, or changes its duration.
     * Alternative usage: Dnd.setSnooze
     * Documentation: https://api.slack.com/methods/dnd.setSnooze
     * @param options Request options.
     */
    async setDndSnooze(options) {
        return this.Dnd.setSnooze(options);
    }
    /**
     * Retrieves the Do Not Disturb status for up to 50 users on a team.
     * Alternative usage: Dnd.getTeamInfo
     * Documentation: https://api.slack.com/methods/dnd.teamInfo
     * @param options Request options.
     */
    async getDndTeamInfo(options) {
        return this.Dnd.getTeamInfo(options);
    }
    /**
     * Lists custom emoji for a team.
     * Alternative usage: Emoji.getEmojis
     * Documentation: https://api.slack.com/methods/emoji.list
     * @param options Request options.
     */
    async getEmojis(options) {
        return this.Emoji.getEmojis(options);
    }
    /**
     * Deletes a file.
     * Alternative usage: File.deleteFile
     * Documentation: https://api.slack.com/methods/files.delete
     * @param options Request options.
     */
    async deleteFile(options) {
        return this.File.deleteFile(options);
    }
    /**
     * Gets information about a file.
     * Alternative usage: File.getInfo
     * Documentation: https://api.slack.com/methods/files.info
     * @param options Request options.
     */
    async getFileInfo(options) {
        return this.File.getInfo(options);
    }
    /**
     * List for a team, in a channel, or from a user with applied filters.
     * Alternative usage: File.getFiles
     * Documentation: https://api.slack.com/methods/files.list
     * @param options Request options.
     */
    async getFiles(options) {
        return this.File.getFiles(options);
    }
    /**
     * Uploads or creates a file.
     * Recommended usage: File.uploadFile
     * Documentation: https://api.slack.com/methods/files.upload
     * @param options Request options.
     */
    async uploadFile(options) {
        return this.File.uploadFile(options);
    }
    /**
     * Deletes an existing comment on a file.
     * Alternative usage: File.Comment.deleteComment
     * Documentation: https://api.slack.com/methods/files.comments.delete
     * @param options Request options.
     */
    async deleteFileComment(options) {
        return this.File.Comment.deleteComment(options);
    }
    /**
     * Revokes public/external sharing access for a file
     * Alternative usage: File.PublicUrl.revokePublicUrl
     * Documentation: https://api.slack.com/methods/files.revokePublicURL
     * @param options Request options.
     */
    async revokeFilePublicUrl(options) {
        return this.File.PublicUrl.revokePublicUrl(options);
    }
    /**
     * Enables a file for public/external sharing.
     * Alternative usage: File.PublicUrl.createPublicUrl
     * Documentation: https://api.slack.com/methods/files.sharedPublicURL
     * @param options Request options.
     */
    async createFilePublicUrl(options) {
        return this.File.PublicUrl.createPublicUrl(options);
    }
    /**
     * Adds a file from a remote service
     * Alternative usage: File.Remote.addFile
     * Documentation: https://api.slack.com/methods/files.remote.add
     * @param options Request options.
     */
    async addRemoteFile(options) {
        return this.File.Remote.addFile(options);
    }
    /**
     * Retrieve information about a remote file added to Slack
     * Alternative usage: File.Remote.getInfo
     * Documentation: https://api.slack.com/methods/files.remote.info
     * @param options Request options.
     */
    async getRemoteFileInfo(options) {
        return this.File.Remote.getInfo(options);
    }
    /**
     * Retrieve information about a remote file added to Slack
     * Alternative usage: File.Remote.getFiles
     * Documentation: https://api.slack.com/methods/files.remote.list
     * @param options Request options.
     */
    async getRemoteFiles(options) {
        return this.File.Remote.getFiles(options);
    }
    /**
     * Remove a remote file.
     * Alternative usage: File.Remote.removeFile
     * Documentation: https://api.slack.com/methods/files.remote.remove
     * @param options Request options.
     */
    async removeRemoteFile(options) {
        return this.File.Remote.removeFile(options);
    }
    /**
     * Share a remote file into a channel.
     * Alternative usage: File.Remote.shareFile
     * Documentation: https://api.slack.com/methods/files.remote.share
     * @param options Request options.
     */
    async shareRemoteFile(options) {
        return this.File.Remote.shareFile(options);
    }
    /**
     * Updates an existing remote file.
     * Alternative usage: File.Remote.updateFile
     * Documentation: https://api.slack.com/methods/files.remote.update
     * @param options Request options.
     */
    async updateRemoteFile(options) {
        return this.File.Remote.updateFile(options);
    }
    /**
     * Adds a reaction to an item.
     * Alternative usage: Reaction.addReaction
     * Documentation: https://api.slack.com/methods/reactions.add
     * @param options Request options.
     */
    async addReaction(options) {
        return this.Reaction.addReaction(options);
    }
    /**
     * Gets reactions for an item.
     * Alternative usage: Reaction.getReaction
     * Documentation: https://api.slack.com/methods/reactions.get
     * @param options Request options.
     */
    async getReaction(options) {
        return this.Reaction.getReaction(options);
    }
    /**
     * Lists reactions made by a user.
     * Alternative usage: Reaction.getReactions
     * Documentation: https://api.slack.com/methods/reactions.list
     * @param options Request options.
     */
    async getReactions(options) {
        return this.Reaction.getReactions(options);
    }
    /**
     * Removes a reaction from an item.
     * Alternative usage: Reaction.removeReaction
     * Documentation: https://api.slack.com/methods/reactions.remove
     * @param options Request options.
     */
    async removeReaction(options) {
        return this.Reaction.removeReaction(options);
    }
    /**
     * Searches for messages matching a query.
     * Alternative usage: Search.searchMessages
     * Documentation: https://api.slack.com/methods/search.messages
     * @param options Request options.
     */
    async searchMessages(options) {
        return this.Search.searchMessages(options);
    }
    /**
     * Gets the access logs for the current team.
     * Alternative usage: Team.getAccessLogs
     * Documentation: https://api.slack.com/methods/team.accessLogs
     * @param options Request options.
     */
    async getTeamAccessLogs(options) {
        return this.Team.getAccessLogs(options);
    }
    /**
     * Gets billable users information for the current team.
     * Alternative usage: Team.getBillableInfo
     * Documentation: https://api.slack.com/methods/team.billableInfo
     * @param options Request options.
     */
    async getTeamBillableInfo(options) {
        return this.Team.getBillableInfo(options);
    }
    /**
     * Gets information about the current team.
     * Alternative usage: Team.getInfo
     * Documentation: https://api.slack.com/methods/team.info
     * @param options Request options.
     */
    async getTeamInfo(options) {
        return this.Team.getInfo(options);
    }
    /**
     * Gets the integration logs for the current team.
     * Alternative usage: Team.getIntegrationLogs
     * Documentation: https://api.slack.com/methods/team.integrationLogs
     * @param options Request options.
     */
    async getTeamIntegrationLogs(options) {
        return this.Team.getIntegrationLogs(options);
    }
    /**
     * Retrieve a team's profile.
     * Alternative usage: Team.Profile.getProfile
     * Documentation: https://api.slack.com/methods/team.profile.get
     * @param options Request options.
     */
    async getTeamProfile(options) {
        return this.Team.Profile.getProfile(options);
    }
    /**
     * Create a User Group
     * Alternative usage: UserGroup.createUserGroup
     * Documentation: https://api.slack.com/methods/usergroups.create
     * @param options Request options.
     */
    async createUserGroup(options) {
        return this.UserGroup.createUserGroup(options);
    }
    /**
     * Disable an existing User Group
     * Alternative usage: UserGroup.disableUserGroup
     * Documentation: https://api.slack.com/methods/usergroups.disable
     * @param options Request options.
     */
    async disableUserGroup(options) {
        return this.UserGroup.disableUserGroup(options);
    }
    /**
     * Enable a User Group
     * Alternative usage: UserGroup.enableUserGroup
     * Documentation: https://api.slack.com/methods/usergroups.enable
     * @param options Request options.
     */
    async enableUserGroup(options) {
        return this.UserGroup.enableUserGroup(options);
    }
    /**
     * List all User Groups for a team
     * Alternative usage: UserGroup.getUserGroups
     * Documentation: https://api.slack.com/methods/usergroups.list
     * @param options Request options.
     */
    async getUserGroups(options) {
        return this.UserGroup.getUserGroups(options);
    }
    /**
     * Update an existing User Group
     * Alternative usage: UserGroup.updateUserGroup
     * Documentation: https://api.slack.com/methods/usergroups.update
     * @param options Request options.
     */
    async updateUserGroup(options) {
        return this.UserGroup.updateUserGroup(options);
    }
    /**
     * List all users in a User Group
     * Alternative usage: UserGroup.User.getUsers
     * Documentation: https://api.slack.com/methods/usergroups.users.list
     * @param options Request options.
     */
    async getUsersInUserGroup(options) {
        return this.UserGroup.User.getUsers(options);
    }
    /**
     * Update the list of users for a User Group
     * Alternative usage: UserGroup.User.updateUsers
     * Documentation: https://api.slack.com/methods/usergroups.users.update
     * @param options Request options.
     */
    async updateUsersInUserGroup(options) {
        return this.UserGroup.User.updateUsers(options);
    }
    /**
     * Send message back to Slack using the response_url in the event payload.
     * Recommended usage: Reply.postMessage
     * Documentation: https://api.slack.com/interactivity/handling#message_responses
     * @param options Request options.
     */
    async postReplyMessage(options) {
        return this.Reply.postMessage(options);
    }
}
class AllUserGroup {
    constructor(Admin, View, User, Reminders, Pins, Bot, Chat, Conversation, Dialog, Dnd, Emoji, File, Reaction, Search, Team, UserGroup) {
        this.Admin = Admin;
        this.View = View;
        this.User = User;
        this.Reminders = Reminders;
        this.Pins = Pins;
        this.Bot = Bot;
        this.Chat = Chat;
        this.Conversation = Conversation;
        this.Dialog = Dialog;
        this.Dnd = Dnd;
        this.Emoji = Emoji;
        this.File = File;
        this.Reaction = Reaction;
        this.Search = Search;
        this.Team = Team;
        this.UserGroup = UserGroup;
    }
    /**
     * Set an existing guest user, admin user, or owner to be a regular user.
     * Alternative usage: Admin.Users.setRegular
     * Documentation: https://api.slack.com/methods/admin.users.setRegular
     * @param options Request options.
     */
    async adminSetRegularUser(options) {
        return this.Admin.Users.setRegular(options);
    }
    /**
     * Set an existing guest, regular user, or admin user to be a workspace owner.
     * Alternative usage: Admin.Users.setOwner
     * Documentation: https://api.slack.com/methods/admin.users.setOwner
     * @param options Request options.
     */
    async adminSetOwnerUser(options) {
        return this.Admin.Users.setOwner(options);
    }
    /**
     * Set an expiration for a guest user
     * Alternative usage: Admin.Users.setExpiration
     * Documentation: https://api.slack.com/methods/admin.users.setExpiration
     * @param options Request options.
     */
    async adminSetUserExpiration(options) {
        return this.Admin.Users.setExpiration(options);
    }
    /**
     * Set an existing guest, regular user, or owner to be an admin user.
     * Alternative usage: Admin.Users.setAdmin
     * Documentation: https://api.slack.com/methods/admin.users.setAdmin
     * @param options Request options.
     */
    async adminSetAdminUser(options) {
        return this.Admin.Users.setAdmin(options);
    }
    /**
     * Remove a user from a workspace.
     * Alternative usage: Admin.Users.removeUser
     * Documentation: https://api.slack.com/methods/admin.users.remove
     * @param options Request options.
     */
    async adminRemoveUser(options) {
        return this.Admin.Users.removeUser(options);
    }
    /**
     * List users on a workspace
     * Alternative usage: Admin.Users.getUsers
     * Documentation: https://api.slack.com/methods/admin.users.list
     * @param options Request options.
     */
    async adminGetUsers(options) {
        return this.Admin.Users.getUsers(options);
    }
    /**
     * Invite a user to a workspace.
     * Recommended usage: Admin.Users.inviteUser
     * Documentation: https://api.slack.com/methods/admin.users.invite
     * @param options Request options.
     */
    async adminInviteUser(options) {
        return this.Admin.Users.inviteUser(options);
    }
    /**
     * Add an Enterprise user to a workspace.
     * Recommended usage: Admin.Users.assignUser
     * Documentation: https://api.slack.com/methods/admin.users.assign
     * @param options Request options.
     */
    async adminAssignUser(options) {
        return this.Admin.Users.assignUser(options);
    }
    /**
     * Update an existing view.
     * Alternative usage: View.updateView
     * Documentation: https://api.slack.com/methods/views.update
     * @param options Request options.
     */
    async updateView(options) {
        return this.View.updateView(options);
    }
    /**
     * Push a view onto the stack of a root view.
     * Alternative usage: View.pushView
     * Documentation: https://api.slack.com/methods/views.push
     * @param options Request options.
     */
    async pushView(options) {
        return this.View.pushView(options);
    }
    /**
     * Open a view for a user.
     * Alternative usage: View.openView
     * Documentation: https://api.slack.com/methods/views.open
     * @param options Request options.
     */
    async openView(options) {
        return this.View.openView(options);
    }
    /**
     * Find a user with an email address.
     * Alternative usage: User.getUserByEmail
     * Documentation: https://api.slack.com/methods/users.lookupByEmail
     * @param options Request options.
     */
    async getUserByEmail(options) {
        return this.User.getUserByEmail(options);
    }
    /**
     * Lists all users in a Slack team.
     * Alternative usage: User.getUsers
     * Documentation: https://api.slack.com/methods/users.list
     * @param options Request options.
     */
    async getUsers(options) {
        return this.User.getUsers(options);
    }
    /**
     * Gets information about a user.
     * Alternative usage: User.getInfo
     * Documentation: https://api.slack.com/methods/users.info
     * @param options Request options.
     */
    async getUserInfo(options) {
        return this.User.getInfo(options);
    }
    /**
     * Get a user's identity.
     * Alternative usage: User.getIdentity
     * Documentation: https://api.slack.com/methods/users.identity
     * @param options Request options.
     */
    async getUserIdentity(options) {
        return this.User.getIdentity(options);
    }
    /**
     * List conversations the calling user may access.
     * Alternative usage: User.getConversations
     * Documentation: https://api.slack.com/methods/users.conversations
     * @param options Request options.
     */
    async getUserConversations(options) {
        return this.User.getConversations(options);
    }
    /**
     * Gets user presence information.
     * Alternative usage: User.getPresence
     * Documentation: https://api.slack.com/methods/users.getPresence
     * @param options Request options.
     */
    async getUserPresence(options) {
        return this.User.getPresence(options);
    }
    /**
     * Manually sets user presence.
     * Alternative usage: User.setPresence
     * Documentation: https://api.slack.com/methods/users.setPresence
     * @param options Request options.
     */
    async setUserPresence(options) {
        return this.User.setPresence(options);
    }
    /**
     * Set the profile information for a user.
     * Alternative usage: User.Profile.setProfile
     * Documentation: https://api.slack.com/methods/users.profile.set
     * @param options Request options.
     */
    async setUserProfile(options) {
        return this.User.Profile.setProfile(options);
    }
    /**
     * Retrieves a user's profile information.
     * Alternative usage: User.Profile.getProfile
     * Documentation: https://api.slack.com/methods/users.profile.get
     * @param options Request options.
     */
    async getUserProfile(options) {
        return this.User.Profile.getProfile(options);
    }
    /**
     * Lists all reminders created by or for a given user.
     * Alternative usage: Reminders.getReminders
     * Documentation: https://api.slack.com/methods/reminders.list
     * @param options Request options.
     */
    async getReminders(options) {
        return this.Reminders.getReminders(options);
    }
    /**
     * Gets information about a reminder.
     * Alternative usage: Reminders.getInfo
     * Documentation: https://api.slack.com/methods/reminders.info
     * @param options Request options.
     */
    async getReminderInfo(options) {
        return this.Reminders.getInfo(options);
    }
    /**
     * Deletes a reminder.
     * Alternative usage: Reminders.deleteReminder
     * Documentation: https://api.slack.com/methods/reminders.delete
     * @param options Request options.
     */
    async deleteReminder(options) {
        return this.Reminders.deleteReminder(options);
    }
    /**
     * Marks a reminder as complete.
     * Alternative usage: Reminders.completeReminder
     * Documentation: https://api.slack.com/methods/reminders.complete
     * @param options Request options.
     */
    async completeReminder(options) {
        return this.Reminders.completeReminder(options);
    }
    /**
     * Creates a reminder.
     * Alternative usage: Reminders.addReminder
     * Documentation: https://api.slack.com/methods/reminders.add
     * @param options Request options.
     */
    async addReminder(options) {
        return this.Reminders.addReminder(options);
    }
    /**
     * Un-pins an item from a channel.
     * Alternative usage: Pins.removePin
     * Documentation: https://api.slack.com/methods/pins.remove
     * @param options Request options.
     */
    async removePin(options) {
        return this.Pins.removePin(options);
    }
    /**
     * Lists items pinned to a channel.
     * Alternative usage: Pins.getPins
     * Documentation: https://api.slack.com/methods/pins.list
     * @param options Request options.
     */
    async getPins(options) {
        return this.Pins.getPins(options);
    }
    /**
     * Pins an item to a channel.
     * Alternative usage: Pins.addPin
     * Documentation: https://api.slack.com/methods/pins.add
     * @param options Request options.
     */
    async addPin(options) {
        return this.Pins.addPin(options);
    }
    /**
     * Gets information about a bot user.
     * Alternative usage: Bot.getInfo
     * Documentation: https://api.slack.com/methods/bots.info
     * @param options Request options.
     */
    async getBotInfo(options) {
        return this.Bot.getInfo(options);
    }
    /**
     * Deletes a message.
     * Alternative usage: Chat.deleteMessage
     * Documentation: https://api.slack.com/methods/chat.delete
     * @param options Request options.
     */
    async deleteChatMessage(options) {
        return this.Chat.deleteMessage(options);
    }
    /**
     * Deletes a pending scheduled message from the queue.
     * Alternative usage: Chat.deleteScheduledMessage
     * Documentation: https://api.slack.com/methods/chat.deleteScheduledMessage
     * @param options Request options.
     */
    async deleteChatScheduledMessage(options) {
        return this.Chat.deleteScheduledMessage(options);
    }
    /**
     * Retrieve a permalink URL for a specific extant message
     * Alternative usage: Chat.getPermalink
     * Documentation: https://api.slack.com/methods/chat.getPermalink
     * @param options Request options.
     */
    async getChatPermalink(options) {
        return this.Chat.getPermalink(options);
    }
    /**
     * Share a me message into a channel.
     * Alternative usage: Chat.postMeMessage
     * Documentation: https://api.slack.com/methods/chat.meMessage
     * @param options Request options.
     */
    async postChatMeMessage(options) {
        return this.Chat.postMeMessage(options);
    }
    /**
     * Sends an ephemeral message to a user in a channel.
     * Alternative usage: Chat.postEphemeralMessage
     * Documentation: https://api.slack.com/methods/chat.postEphemeral
     * @param options Request options.
     */
    async postChatEphemeralMessage(options) {
        return this.Chat.postEphemeralMessage(options);
    }
    /**
     * Sends a message to a channel.
     * Alternative usage: Chat.postMessage
     * Documentation: https://api.slack.com/methods/chat.postMessage
     * @param options Request options.
     */
    async postChatMessage(options) {
        return this.Chat.postMessage(options);
    }
    /**
     * Schedules a message to be sent to a channel.
     * Alternative usage: Chat.scheduleMessage
     * Documentation: https://api.slack.com/methods/chat.scheduleMessage
     * @param options Request options.
     */
    async scheduleChatMessage(options) {
        return this.Chat.scheduleMessage(options);
    }
    /**
     * Returns a list of scheduled messages.
     * Alternative usage: Chat.getScheduledMessages
     * Documentation: https://api.slack.com/methods/chat.scheduledMessages.list
     * @param options Request options.
     */
    async getChatScheduledMessages(options) {
        return this.Chat.getScheduledMessages(options);
    }
    /**
     * Provide custom unfurl behavior for user-posted URLs
     * Alternative usage: Chat.unfurlMessage
     * Documentation: https://api.slack.com/methods/chat.unfurl
     * @param options Request options.
     */
    async unfurlChatMessage(options) {
        return this.Chat.unfurlMessage(options);
    }
    /**
     * Updates a message.
     * Alternative usage: Chat.updateMessage
     * Documentation: https://api.slack.com/methods/chat.update
     * @param options Request options.
     */
    async updateChatMessage(options) {
        return this.Chat.updateMessage(options);
    }
    /**
     * Archives a conversation.
     * Alternative usage: Conversation.archiveConversation
     * Documentation: https://api.slack.com/methods/conversations.archive
     * @param options Request options.
     */
    async archiveConversation(options) {
        return this.Conversation.archiveConversation(options);
    }
    /**
     * Closes a direct message or multi-person direct message.
     * Alternative usage: Conversation.closeConversation
     * Documentation: https://api.slack.com/methods/conversations.close
     * @param options Request options.
     */
    async closeConversation(options) {
        return this.Conversation.closeConversation(options);
    }
    /**
     * Initiates a public or private channel-based conversation
     * Alternative usage: Conversation.createConversation
     * Documentation: https://api.slack.com/methods/conversations.create
     * @param options Request options.
     */
    async createConversation(options) {
        return this.Conversation.createConversation(options);
    }
    /**
     * Fetches a conversation's history of messages and events.
     * Alternative usage: Conversation.getHistory
     * Documentation: https://api.slack.com/methods/conversations.history
     * @param options Request options.
     */
    async getConversationHistory(options) {
        return this.Conversation.getHistory(options);
    }
    /**
     * Retrieve information about a conversation.
     * Alternative usage: Conversation.getInfo
     * Documentation: https://api.slack.com/methods/conversations.info
     * @param options Request options.
     */
    async getConversationInfo(options) {
        return this.Conversation.getInfo(options);
    }
    /**
     * Invites users to a channel.
     * Alternative usage: Conversation.inviteUser
     * Documentation: https://api.slack.com/methods/conversations.invite
     * @param options Request options.
     */
    async inviteUserToConversation(options) {
        return this.Conversation.inviteUser(options);
    }
    /**
     * Joins an existing conversation.
     * Alternative usage: Conversation.joinConversation
     * Documentation: https://api.slack.com/methods/conversations.join
     * @param options Request options.
     */
    async joinConversation(options) {
        return this.Conversation.joinConversation(options);
    }
    /**
     * Removes a user from a conversation.
     * Alternative usage: Conversation.kickUser
     * Documentation: https://api.slack.com/methods/conversations.kick
     * @param options Request options.
     */
    async kickUserFromConversation(options) {
        return this.Conversation.kickUser(options);
    }
    /**
     * Leaves a conversation.
     * Alternative usage: Conversation.leaveConversation
     * Documentation: https://api.slack.com/methods/conversations.leave
     * @param options Request options.
     */
    async leaveConversation(options) {
        return this.Conversation.leaveConversation(options);
    }
    /**
     * Lists all channels in a Slack team.
     * Recommended usage: Conversation.getConversations
     * Documentation: https://api.slack.com/methods/conversations.list
     * @param options Request options.
     */
    async getConversations(options) {
        return this.Conversation.getConversations(options);
    }
    /**
     * Retrieve members of a conversation.
     * Alternative usage: Conversation.getMembers
     * Documentation: https://api.slack.com/methods/conversations.members
     * @param options Request options.
     */
    async getConversationMembers(options) {
        return this.Conversation.getMembers(options);
    }
    /**
     * Opens or resumes a direct message or multi-person direct message.
     * Alternative usage: Conversation.openConversation
     * Documentation: https://api.slack.com/methods/conversations.open
     * @param options Request options.
     */
    async openConversation(options) {
        return this.Conversation.openConversation(options);
    }
    /**
     * Renames a conversation.
     * Alternative usage: Conversation.renameConversation
     * Documentation: https://api.slack.com/methods/conversations.rename
     * @param options Request options.
     */
    async renameConversation(options) {
        return this.Conversation.renameConversation(options);
    }
    /**
     * Retrieve a thread of messages posted to a conversation
     * Alternative usage: Conversation.getReplies
     * Documentation: https://api.slack.com/methods/conversations.replies
     * @param options Request options.
     */
    async getConversationReplies(options) {
        return this.Conversation.getReplies(options);
    }
    /**
     * Sets the purpose for a conversation.
     * Alternative usage: Conversation.setPurpose
     * Documentation: https://api.slack.com/methods/conversations.setPurpose
     * @param options Request options.
     */
    async setConversationPurpose(options) {
        return this.Conversation.setPurpose(options);
    }
    /**
     * Sets the topic for a conversation.
     * Alternative usage: Conversation.setTopic
     * Documentation: https://api.slack.com/methods/conversations.setTopic
     * @param options Request options.
     */
    async setConversationTopic(options) {
        return this.Conversation.setTopic(options);
    }
    /**
     * Reverses conversation archival.
     * Alternative usage: Conversation.unarchiveConversation
     * Documentation: https://api.slack.com/methods/conversations.unarchive
     * @param options Request options.
     */
    async unarchiveConversation(options) {
        return this.Conversation.unarchiveConversation(options);
    }
    /**
     * Open a dialog with a user
     * Alternative usage: Dialog.openDialog
     * Documentation: https://api.slack.com/methods/dialog.open
     * @param options Request options.
     */
    async openDialog(options) {
        return this.Dialog.openDialog(options);
    }
    /**
     * Ends the current user's Do Not Disturb session immediately.
     * Alternative usage: Dnd.endDnd
     * Documentation: https://api.slack.com/methods/dnd.endDnd
     * @param options Request options.
     */
    async endDnd(options) {
        return this.Dnd.endDnd(options);
    }
    /**
     * Ends the current user's snooze mode immediately.
     * Alternative usage: Dnd.endSnooze
     * Documentation: https://api.slack.com/methods/dnd.endSnooze
     * @param options Request options.
     */
    async endDndSnooze(options) {
        return this.Dnd.endSnooze(options);
    }
    /**
     * Retrieves a user's current Do Not Disturb status.
     * Alternative usage: Dnd.getInfo
     * Documentation: https://api.slack.com/methods/dnd.info
     * @param options Request options.
     */
    async getDndInfo(options) {
        return this.Dnd.getInfo(options);
    }
    /**
     * Turns on Do Not Disturb mode for the current user, or changes its duration.
     * Alternative usage: Dnd.setSnooze
     * Documentation: https://api.slack.com/methods/dnd.setSnooze
     * @param options Request options.
     */
    async setDndSnooze(options) {
        return this.Dnd.setSnooze(options);
    }
    /**
     * Retrieves the Do Not Disturb status for up to 50 users on a team.
     * Alternative usage: Dnd.getTeamInfo
     * Documentation: https://api.slack.com/methods/dnd.teamInfo
     * @param options Request options.
     */
    async getDndTeamInfo(options) {
        return this.Dnd.getTeamInfo(options);
    }
    /**
     * Lists custom emoji for a team.
     * Alternative usage: Emoji.getEmojis
     * Documentation: https://api.slack.com/methods/emoji.list
     * @param options Request options.
     */
    async getEmojis(options) {
        return this.Emoji.getEmojis(options);
    }
    /**
     * Deletes a file.
     * Alternative usage: File.deleteFile
     * Documentation: https://api.slack.com/methods/files.delete
     * @param options Request options.
     */
    async deleteFile(options) {
        return this.File.deleteFile(options);
    }
    /**
     * Gets information about a file.
     * Alternative usage: File.getInfo
     * Documentation: https://api.slack.com/methods/files.info
     * @param options Request options.
     */
    async getFileInfo(options) {
        return this.File.getInfo(options);
    }
    /**
     * List for a team, in a channel, or from a user with applied filters.
     * Alternative usage: File.getFiles
     * Documentation: https://api.slack.com/methods/files.list
     * @param options Request options.
     */
    async getFiles(options) {
        return this.File.getFiles(options);
    }
    /**
     * Uploads or creates a file.
     * Recommended usage: File.uploadFile
     * Documentation: https://api.slack.com/methods/files.upload
     * @param options Request options.
     */
    async uploadFile(options) {
        return this.File.uploadFile(options);
    }
    /**
     * Deletes an existing comment on a file.
     * Alternative usage: File.Comment.deleteComment
     * Documentation: https://api.slack.com/methods/files.comments.delete
     * @param options Request options.
     */
    async deleteFileComment(options) {
        return this.File.Comment.deleteComment(options);
    }
    /**
     * Revokes public/external sharing access for a file
     * Alternative usage: File.PublicUrl.revokePublicUrl
     * Documentation: https://api.slack.com/methods/files.revokePublicURL
     * @param options Request options.
     */
    async revokeFilePublicUrl(options) {
        return this.File.PublicUrl.revokePublicUrl(options);
    }
    /**
     * Enables a file for public/external sharing.
     * Alternative usage: File.PublicUrl.createPublicUrl
     * Documentation: https://api.slack.com/methods/files.sharedPublicURL
     * @param options Request options.
     */
    async createFilePublicUrl(options) {
        return this.File.PublicUrl.createPublicUrl(options);
    }
    /**
     * Retrieve information about a remote file added to Slack
     * Alternative usage: File.Remote.getInfo
     * Documentation: https://api.slack.com/methods/files.remote.info
     * @param options Request options.
     */
    async getRemoteFileInfo(options) {
        return this.File.Remote.getInfo(options);
    }
    /**
     * Retrieve information about a remote file added to Slack
     * Alternative usage: File.Remote.getFiles
     * Documentation: https://api.slack.com/methods/files.remote.list
     * @param options Request options.
     */
    async getRemoteFiles(options) {
        return this.File.Remote.getFiles(options);
    }
    /**
     * Share a remote file into a channel.
     * Alternative usage: File.Remote.shareFile
     * Documentation: https://api.slack.com/methods/files.remote.share
     * @param options Request options.
     */
    async shareRemoteFile(options) {
        return this.File.Remote.shareFile(options);
    }
    /**
     * Adds a reaction to an item.
     * Alternative usage: Reaction.addReaction
     * Documentation: https://api.slack.com/methods/reactions.add
     * @param options Request options.
     */
    async addReaction(options) {
        return this.Reaction.addReaction(options);
    }
    /**
     * Gets reactions for an item.
     * Alternative usage: Reaction.getReaction
     * Documentation: https://api.slack.com/methods/reactions.get
     * @param options Request options.
     */
    async getReaction(options) {
        return this.Reaction.getReaction(options);
    }
    /**
     * Lists reactions made by a user.
     * Alternative usage: Reaction.getReactions
     * Documentation: https://api.slack.com/methods/reactions.list
     * @param options Request options.
     */
    async getReactions(options) {
        return this.Reaction.getReactions(options);
    }
    /**
     * Removes a reaction from an item.
     * Alternative usage: Reaction.removeReaction
     * Documentation: https://api.slack.com/methods/reactions.remove
     * @param options Request options.
     */
    async removeReaction(options) {
        return this.Reaction.removeReaction(options);
    }
    /**
     * Searches for messages matching a query.
     * Alternative usage: Search.searchMessages
     * Documentation: https://api.slack.com/methods/search.messages
     * @param options Request options.
     */
    async searchMessages(options) {
        return this.Search.searchMessages(options);
    }
    /**
     * Gets the access logs for the current team.
     * Alternative usage: Team.getAccessLogs
     * Documentation: https://api.slack.com/methods/team.accessLogs
     * @param options Request options.
     */
    async getTeamAccessLogs(options) {
        return this.Team.getAccessLogs(options);
    }
    /**
     * Gets billable users information for the current team.
     * Alternative usage: Team.getBillableInfo
     * Documentation: https://api.slack.com/methods/team.billableInfo
     * @param options Request options.
     */
    async getTeamBillableInfo(options) {
        return this.Team.getBillableInfo(options);
    }
    /**
     * Gets information about the current team.
     * Alternative usage: Team.getInfo
     * Documentation: https://api.slack.com/methods/team.info
     * @param options Request options.
     */
    async getTeamInfo(options) {
        return this.Team.getInfo(options);
    }
    /**
     * Gets the integration logs for the current team.
     * Alternative usage: Team.getIntegrationLogs
     * Documentation: https://api.slack.com/methods/team.integrationLogs
     * @param options Request options.
     */
    async getTeamIntegrationLogs(options) {
        return this.Team.getIntegrationLogs(options);
    }
    /**
     * Retrieve a team's profile.
     * Alternative usage: Team.Profile.getProfile
     * Documentation: https://api.slack.com/methods/team.profile.get
     * @param options Request options.
     */
    async getTeamProfile(options) {
        return this.Team.Profile.getProfile(options);
    }
    /**
     * Create a User Group
     * Alternative usage: UserGroup.createUserGroup
     * Documentation: https://api.slack.com/methods/usergroups.create
     * @param options Request options.
     */
    async createUserGroup(options) {
        return this.UserGroup.createUserGroup(options);
    }
    /**
     * Disable an existing User Group
     * Alternative usage: UserGroup.disableUserGroup
     * Documentation: https://api.slack.com/methods/usergroups.disable
     * @param options Request options.
     */
    async disableUserGroup(options) {
        return this.UserGroup.disableUserGroup(options);
    }
    /**
     * Enable a User Group
     * Alternative usage: UserGroup.enableUserGroup
     * Documentation: https://api.slack.com/methods/usergroups.enable
     * @param options Request options.
     */
    async enableUserGroup(options) {
        return this.UserGroup.enableUserGroup(options);
    }
    /**
     * List all User Groups for a team
     * Alternative usage: UserGroup.getUserGroups
     * Documentation: https://api.slack.com/methods/usergroups.list
     * @param options Request options.
     */
    async getUserGroups(options) {
        return this.UserGroup.getUserGroups(options);
    }
    /**
     * Update an existing User Group
     * Alternative usage: UserGroup.updateUserGroup
     * Documentation: https://api.slack.com/methods/usergroups.update
     * @param options Request options.
     */
    async updateUserGroup(options) {
        return this.UserGroup.updateUserGroup(options);
    }
    /**
     * List all users in a User Group
     * Alternative usage: UserGroup.User.getUsers
     * Documentation: https://api.slack.com/methods/usergroups.users.list
     * @param options Request options.
     */
    async getUsersInUserGroup(options) {
        return this.UserGroup.User.getUsers(options);
    }
    /**
     * Update the list of users for a User Group
     * Alternative usage: UserGroup.User.updateUsers
     * Documentation: https://api.slack.com/methods/usergroups.users.update
     * @param options Request options.
     */
    async updateUsersInUserGroup(options) {
        return this.UserGroup.User.updateUsers(options);
    }
}
class AllBotGroup {
    constructor(View, User, Pins, Bot, Chat, Conversation, Dialog, Dnd, Emoji, File, Reaction, Team, UserGroup) {
        this.View = View;
        this.User = User;
        this.Pins = Pins;
        this.Bot = Bot;
        this.Chat = Chat;
        this.Conversation = Conversation;
        this.Dialog = Dialog;
        this.Dnd = Dnd;
        this.Emoji = Emoji;
        this.File = File;
        this.Reaction = Reaction;
        this.Team = Team;
        this.UserGroup = UserGroup;
    }
    /**
     * Update an existing view.
     * Alternative usage: View.updateView
     * Documentation: https://api.slack.com/methods/views.update
     * @param options Request options.
     */
    async updateView(options) {
        return this.View.updateView(options);
    }
    /**
     * Push a view onto the stack of a root view.
     * Alternative usage: View.pushView
     * Documentation: https://api.slack.com/methods/views.push
     * @param options Request options.
     */
    async pushView(options) {
        return this.View.pushView(options);
    }
    /**
     * Publish a static view for a User.
     * Alternative usage: View.publishView
     * Documentation: https://api.slack.com/methods/views.publish
     * @param options Request options.
     */
    async publishView(options) {
        return this.View.publishView(options);
    }
    /**
     * Open a view for a user.
     * Alternative usage: View.openView
     * Documentation: https://api.slack.com/methods/views.open
     * @param options Request options.
     */
    async openView(options) {
        return this.View.openView(options);
    }
    /**
     * Find a user with an email address.
     * Alternative usage: User.getUserByEmail
     * Documentation: https://api.slack.com/methods/users.lookupByEmail
     * @param options Request options.
     */
    async getUserByEmail(options) {
        return this.User.getUserByEmail(options);
    }
    /**
     * Lists all users in a Slack team.
     * Alternative usage: User.getUsers
     * Documentation: https://api.slack.com/methods/users.list
     * @param options Request options.
     */
    async getUsers(options) {
        return this.User.getUsers(options);
    }
    /**
     * Gets information about a user.
     * Alternative usage: User.getInfo
     * Documentation: https://api.slack.com/methods/users.info
     * @param options Request options.
     */
    async getUserInfo(options) {
        return this.User.getInfo(options);
    }
    /**
     * List conversations the calling user may access.
     * Alternative usage: User.getConversations
     * Documentation: https://api.slack.com/methods/users.conversations
     * @param options Request options.
     */
    async getUserConversations(options) {
        return this.User.getConversations(options);
    }
    /**
     * Gets user presence information.
     * Alternative usage: User.getPresence
     * Documentation: https://api.slack.com/methods/users.getPresence
     * @param options Request options.
     */
    async getUserPresence(options) {
        return this.User.getPresence(options);
    }
    /**
     * Manually sets user presence.
     * Alternative usage: User.setPresence
     * Documentation: https://api.slack.com/methods/users.setPresence
     * @param options Request options.
     */
    async setUserPresence(options) {
        return this.User.setPresence(options);
    }
    /**
     * Retrieves a user's profile information.
     * Alternative usage: User.Profile.getProfile
     * Documentation: https://api.slack.com/methods/users.profile.get
     * @param options Request options.
     */
    async getUserProfile(options) {
        return this.User.Profile.getProfile(options);
    }
    /**
     * Un-pins an item from a channel.
     * Alternative usage: Pins.removePin
     * Documentation: https://api.slack.com/methods/pins.remove
     * @param options Request options.
     */
    async removePin(options) {
        return this.Pins.removePin(options);
    }
    /**
     * Lists items pinned to a channel.
     * Alternative usage: Pins.getPins
     * Documentation: https://api.slack.com/methods/pins.list
     * @param options Request options.
     */
    async getPins(options) {
        return this.Pins.getPins(options);
    }
    /**
     * Pins an item to a channel.
     * Alternative usage: Pins.addPin
     * Documentation: https://api.slack.com/methods/pins.add
     * @param options Request options.
     */
    async addPin(options) {
        return this.Pins.addPin(options);
    }
    /**
     * Gets information about a bot user.
     * Alternative usage: Bot.getInfo
     * Documentation: https://api.slack.com/methods/bots.info
     * @param options Request options.
     */
    async getBotInfo(options) {
        return this.Bot.getInfo(options);
    }
    /**
     * Deletes a message.
     * Alternative usage: Chat.deleteMessage
     * Documentation: https://api.slack.com/methods/chat.delete
     * @param options Request options.
     */
    async deleteChatMessage(options) {
        return this.Chat.deleteMessage(options);
    }
    /**
     * Deletes a pending scheduled message from the queue.
     * Alternative usage: Chat.deleteScheduledMessage
     * Documentation: https://api.slack.com/methods/chat.deleteScheduledMessage
     * @param options Request options.
     */
    async deleteChatScheduledMessage(options) {
        return this.Chat.deleteScheduledMessage(options);
    }
    /**
     * Retrieve a permalink URL for a specific extant message
     * Alternative usage: Chat.getPermalink
     * Documentation: https://api.slack.com/methods/chat.getPermalink
     * @param options Request options.
     */
    async getChatPermalink(options) {
        return this.Chat.getPermalink(options);
    }
    /**
     * Share a me message into a channel.
     * Alternative usage: Chat.postMeMessage
     * Documentation: https://api.slack.com/methods/chat.meMessage
     * @param options Request options.
     */
    async postChatMeMessage(options) {
        return this.Chat.postMeMessage(options);
    }
    /**
     * Sends an ephemeral message to a user in a channel.
     * Alternative usage: Chat.postEphemeralMessage
     * Documentation: https://api.slack.com/methods/chat.postEphemeral
     * @param options Request options.
     */
    async postChatEphemeralMessage(options) {
        return this.Chat.postEphemeralMessage(options);
    }
    /**
     * Sends a message to a channel.
     * Alternative usage: Chat.postMessage
     * Documentation: https://api.slack.com/methods/chat.postMessage
     * @param options Request options.
     */
    async postChatMessage(options) {
        return this.Chat.postMessage(options);
    }
    /**
     * Schedules a message to be sent to a channel.
     * Alternative usage: Chat.scheduleMessage
     * Documentation: https://api.slack.com/methods/chat.scheduleMessage
     * @param options Request options.
     */
    async scheduleChatMessage(options) {
        return this.Chat.scheduleMessage(options);
    }
    /**
     * Returns a list of scheduled messages.
     * Alternative usage: Chat.getScheduledMessages
     * Documentation: https://api.slack.com/methods/chat.scheduledMessages.list
     * @param options Request options.
     */
    async getChatScheduledMessages(options) {
        return this.Chat.getScheduledMessages(options);
    }
    /**
     * Provide custom unfurl behavior for user-posted URLs
     * Alternative usage: Chat.unfurlMessage
     * Documentation: https://api.slack.com/methods/chat.unfurl
     * @param options Request options.
     */
    async unfurlChatMessage(options) {
        return this.Chat.unfurlMessage(options);
    }
    /**
     * Updates a message.
     * Alternative usage: Chat.updateMessage
     * Documentation: https://api.slack.com/methods/chat.update
     * @param options Request options.
     */
    async updateChatMessage(options) {
        return this.Chat.updateMessage(options);
    }
    /**
     * Archives a conversation.
     * Alternative usage: Conversation.archiveConversation
     * Documentation: https://api.slack.com/methods/conversations.archive
     * @param options Request options.
     */
    async archiveConversation(options) {
        return this.Conversation.archiveConversation(options);
    }
    /**
     * Closes a direct message or multi-person direct message.
     * Alternative usage: Conversation.closeConversation
     * Documentation: https://api.slack.com/methods/conversations.close
     * @param options Request options.
     */
    async closeConversation(options) {
        return this.Conversation.closeConversation(options);
    }
    /**
     * Initiates a public or private channel-based conversation
     * Alternative usage: Conversation.createConversation
     * Documentation: https://api.slack.com/methods/conversations.create
     * @param options Request options.
     */
    async createConversation(options) {
        return this.Conversation.createConversation(options);
    }
    /**
     * Fetches a conversation's history of messages and events.
     * Alternative usage: Conversation.getHistory
     * Documentation: https://api.slack.com/methods/conversations.history
     * @param options Request options.
     */
    async getConversationHistory(options) {
        return this.Conversation.getHistory(options);
    }
    /**
     * Retrieve information about a conversation.
     * Alternative usage: Conversation.getInfo
     * Documentation: https://api.slack.com/methods/conversations.info
     * @param options Request options.
     */
    async getConversationInfo(options) {
        return this.Conversation.getInfo(options);
    }
    /**
     * Invites users to a channel.
     * Alternative usage: Conversation.inviteUser
     * Documentation: https://api.slack.com/methods/conversations.invite
     * @param options Request options.
     */
    async inviteUserToConversation(options) {
        return this.Conversation.inviteUser(options);
    }
    /**
     * Joins an existing conversation.
     * Alternative usage: Conversation.joinConversation
     * Documentation: https://api.slack.com/methods/conversations.join
     * @param options Request options.
     */
    async joinConversation(options) {
        return this.Conversation.joinConversation(options);
    }
    /**
     * Removes a user from a conversation.
     * Alternative usage: Conversation.kickUser
     * Documentation: https://api.slack.com/methods/conversations.kick
     * @param options Request options.
     */
    async kickUserFromConversation(options) {
        return this.Conversation.kickUser(options);
    }
    /**
     * Leaves a conversation.
     * Alternative usage: Conversation.leaveConversation
     * Documentation: https://api.slack.com/methods/conversations.leave
     * @param options Request options.
     */
    async leaveConversation(options) {
        return this.Conversation.leaveConversation(options);
    }
    /**
     * Lists all channels in a Slack team.
     * Recommended usage: Conversation.getConversations
     * Documentation: https://api.slack.com/methods/conversations.list
     * @param options Request options.
     */
    async getConversations(options) {
        return this.Conversation.getConversations(options);
    }
    /**
     * Retrieve members of a conversation.
     * Alternative usage: Conversation.getMembers
     * Documentation: https://api.slack.com/methods/conversations.members
     * @param options Request options.
     */
    async getConversationMembers(options) {
        return this.Conversation.getMembers(options);
    }
    /**
     * Opens or resumes a direct message or multi-person direct message.
     * Alternative usage: Conversation.openConversation
     * Documentation: https://api.slack.com/methods/conversations.open
     * @param options Request options.
     */
    async openConversation(options) {
        return this.Conversation.openConversation(options);
    }
    /**
     * Renames a conversation.
     * Alternative usage: Conversation.renameConversation
     * Documentation: https://api.slack.com/methods/conversations.rename
     * @param options Request options.
     */
    async renameConversation(options) {
        return this.Conversation.renameConversation(options);
    }
    /**
     * Retrieve a thread of messages posted to a conversation
     * Alternative usage: Conversation.getReplies
     * Documentation: https://api.slack.com/methods/conversations.replies
     * @param options Request options.
     */
    async getConversationReplies(options) {
        return this.Conversation.getReplies(options);
    }
    /**
     * Sets the purpose for a conversation.
     * Alternative usage: Conversation.setPurpose
     * Documentation: https://api.slack.com/methods/conversations.setPurpose
     * @param options Request options.
     */
    async setConversationPurpose(options) {
        return this.Conversation.setPurpose(options);
    }
    /**
     * Sets the topic for a conversation.
     * Alternative usage: Conversation.setTopic
     * Documentation: https://api.slack.com/methods/conversations.setTopic
     * @param options Request options.
     */
    async setConversationTopic(options) {
        return this.Conversation.setTopic(options);
    }
    /**
     * Reverses conversation archival.
     * Alternative usage: Conversation.unarchiveConversation
     * Documentation: https://api.slack.com/methods/conversations.unarchive
     * @param options Request options.
     */
    async unarchiveConversation(options) {
        return this.Conversation.unarchiveConversation(options);
    }
    /**
     * Open a dialog with a user
     * Alternative usage: Dialog.openDialog
     * Documentation: https://api.slack.com/methods/dialog.open
     * @param options Request options.
     */
    async openDialog(options) {
        return this.Dialog.openDialog(options);
    }
    /**
     * Retrieves a user's current Do Not Disturb status.
     * Alternative usage: Dnd.getInfo
     * Documentation: https://api.slack.com/methods/dnd.info
     * @param options Request options.
     */
    async getDndInfo(options) {
        return this.Dnd.getInfo(options);
    }
    /**
     * Retrieves the Do Not Disturb status for up to 50 users on a team.
     * Alternative usage: Dnd.getTeamInfo
     * Documentation: https://api.slack.com/methods/dnd.teamInfo
     * @param options Request options.
     */
    async getDndTeamInfo(options) {
        return this.Dnd.getTeamInfo(options);
    }
    /**
     * Lists custom emoji for a team.
     * Alternative usage: Emoji.getEmojis
     * Documentation: https://api.slack.com/methods/emoji.list
     * @param options Request options.
     */
    async getEmojis(options) {
        return this.Emoji.getEmojis(options);
    }
    /**
     * Deletes a file.
     * Alternative usage: File.deleteFile
     * Documentation: https://api.slack.com/methods/files.delete
     * @param options Request options.
     */
    async deleteFile(options) {
        return this.File.deleteFile(options);
    }
    /**
     * Gets information about a file.
     * Alternative usage: File.getInfo
     * Documentation: https://api.slack.com/methods/files.info
     * @param options Request options.
     */
    async getFileInfo(options) {
        return this.File.getInfo(options);
    }
    /**
     * List for a team, in a channel, or from a user with applied filters.
     * Alternative usage: File.getFiles
     * Documentation: https://api.slack.com/methods/files.list
     * @param options Request options.
     */
    async getFiles(options) {
        return this.File.getFiles(options);
    }
    /**
     * Uploads or creates a file.
     * Recommended usage: File.uploadFile
     * Documentation: https://api.slack.com/methods/files.upload
     * @param options Request options.
     */
    async uploadFile(options) {
        return this.File.uploadFile(options);
    }
    /**
     * Deletes an existing comment on a file.
     * Alternative usage: File.Comment.deleteComment
     * Documentation: https://api.slack.com/methods/files.comments.delete
     * @param options Request options.
     */
    async deleteFileComment(options) {
        return this.File.Comment.deleteComment(options);
    }
    /**
     * Adds a file from a remote service
     * Alternative usage: File.Remote.addFile
     * Documentation: https://api.slack.com/methods/files.remote.add
     * @param options Request options.
     */
    async addRemoteFile(options) {
        return this.File.Remote.addFile(options);
    }
    /**
     * Retrieve information about a remote file added to Slack
     * Alternative usage: File.Remote.getInfo
     * Documentation: https://api.slack.com/methods/files.remote.info
     * @param options Request options.
     */
    async getRemoteFileInfo(options) {
        return this.File.Remote.getInfo(options);
    }
    /**
     * Retrieve information about a remote file added to Slack
     * Alternative usage: File.Remote.getFiles
     * Documentation: https://api.slack.com/methods/files.remote.list
     * @param options Request options.
     */
    async getRemoteFiles(options) {
        return this.File.Remote.getFiles(options);
    }
    /**
     * Remove a remote file.
     * Alternative usage: File.Remote.removeFile
     * Documentation: https://api.slack.com/methods/files.remote.remove
     * @param options Request options.
     */
    async removeRemoteFile(options) {
        return this.File.Remote.removeFile(options);
    }
    /**
     * Share a remote file into a channel.
     * Alternative usage: File.Remote.shareFile
     * Documentation: https://api.slack.com/methods/files.remote.share
     * @param options Request options.
     */
    async shareRemoteFile(options) {
        return this.File.Remote.shareFile(options);
    }
    /**
     * Updates an existing remote file.
     * Alternative usage: File.Remote.updateFile
     * Documentation: https://api.slack.com/methods/files.remote.update
     * @param options Request options.
     */
    async updateRemoteFile(options) {
        return this.File.Remote.updateFile(options);
    }
    /**
     * Adds a reaction to an item.
     * Alternative usage: Reaction.addReaction
     * Documentation: https://api.slack.com/methods/reactions.add
     * @param options Request options.
     */
    async addReaction(options) {
        return this.Reaction.addReaction(options);
    }
    /**
     * Gets reactions for an item.
     * Alternative usage: Reaction.getReaction
     * Documentation: https://api.slack.com/methods/reactions.get
     * @param options Request options.
     */
    async getReaction(options) {
        return this.Reaction.getReaction(options);
    }
    /**
     * Lists reactions made by a user.
     * Alternative usage: Reaction.getReactions
     * Documentation: https://api.slack.com/methods/reactions.list
     * @param options Request options.
     */
    async getReactions(options) {
        return this.Reaction.getReactions(options);
    }
    /**
     * Removes a reaction from an item.
     * Alternative usage: Reaction.removeReaction
     * Documentation: https://api.slack.com/methods/reactions.remove
     * @param options Request options.
     */
    async removeReaction(options) {
        return this.Reaction.removeReaction(options);
    }
    /**
     * Gets information about the current team.
     * Alternative usage: Team.getInfo
     * Documentation: https://api.slack.com/methods/team.info
     * @param options Request options.
     */
    async getTeamInfo(options) {
        return this.Team.getInfo(options);
    }
    /**
     * Retrieve a team's profile.
     * Alternative usage: Team.Profile.getProfile
     * Documentation: https://api.slack.com/methods/team.profile.get
     * @param options Request options.
     */
    async getTeamProfile(options) {
        return this.Team.Profile.getProfile(options);
    }
    /**
     * Create a User Group
     * Alternative usage: UserGroup.createUserGroup
     * Documentation: https://api.slack.com/methods/usergroups.create
     * @param options Request options.
     */
    async createUserGroup(options) {
        return this.UserGroup.createUserGroup(options);
    }
    /**
     * Disable an existing User Group
     * Alternative usage: UserGroup.disableUserGroup
     * Documentation: https://api.slack.com/methods/usergroups.disable
     * @param options Request options.
     */
    async disableUserGroup(options) {
        return this.UserGroup.disableUserGroup(options);
    }
    /**
     * Enable a User Group
     * Alternative usage: UserGroup.enableUserGroup
     * Documentation: https://api.slack.com/methods/usergroups.enable
     * @param options Request options.
     */
    async enableUserGroup(options) {
        return this.UserGroup.enableUserGroup(options);
    }
    /**
     * List all User Groups for a team
     * Alternative usage: UserGroup.getUserGroups
     * Documentation: https://api.slack.com/methods/usergroups.list
     * @param options Request options.
     */
    async getUserGroups(options) {
        return this.UserGroup.getUserGroups(options);
    }
    /**
     * Update an existing User Group
     * Alternative usage: UserGroup.updateUserGroup
     * Documentation: https://api.slack.com/methods/usergroups.update
     * @param options Request options.
     */
    async updateUserGroup(options) {
        return this.UserGroup.updateUserGroup(options);
    }
    /**
     * List all users in a User Group
     * Alternative usage: UserGroup.User.getUsers
     * Documentation: https://api.slack.com/methods/usergroups.users.list
     * @param options Request options.
     */
    async getUsersInUserGroup(options) {
        return this.UserGroup.User.getUsers(options);
    }
    /**
     * Update the list of users for a User Group
     * Alternative usage: UserGroup.User.updateUsers
     * Documentation: https://api.slack.com/methods/usergroups.users.update
     * @param options Request options.
     */
    async updateUsersInUserGroup(options) {
        return this.UserGroup.User.updateUsers(options);
    }
}
class AdminGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Users = new AdminUsersGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class AdminUsersGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Set an existing guest user, admin user, or owner to be a regular user.
     * Documentation: https://api.slack.com/methods/admin.users.setRegular
     * @param options Request options.
     */
    async setRegular(options) {
        const { body, headers, errorStrategy, userId } = options;
        const customParams = { userId };
        const request = new Request("POST", `/api/admin.users.setRegular`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Set an existing guest, regular user, or admin user to be a workspace owner.
     * Documentation: https://api.slack.com/methods/admin.users.setOwner
     * @param options Request options.
     */
    async setOwner(options) {
        const { body, headers, errorStrategy, userId } = options;
        const customParams = { userId };
        const request = new Request("POST", `/api/admin.users.setOwner`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Set an expiration for a guest user
     * Documentation: https://api.slack.com/methods/admin.users.setExpiration
     * @param options Request options.
     */
    async setExpiration(options) {
        const { body, headers, errorStrategy, userId } = options;
        const customParams = { userId };
        const request = new Request("POST", `/api/admin.users.setExpiration`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Set an existing guest, regular user, or owner to be an admin user.
     * Documentation: https://api.slack.com/methods/admin.users.setAdmin
     * @param options Request options.
     */
    async setAdmin(options) {
        const { body, headers, errorStrategy, userId } = options;
        const customParams = { userId };
        const request = new Request("POST", `/api/admin.users.setAdmin`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Remove a user from a workspace.
     * Documentation: https://api.slack.com/methods/admin.users.remove
     * @param options Request options.
     */
    async removeUser(options) {
        const { body, headers, errorStrategy, userId } = options;
        const customParams = { userId };
        const request = new Request("POST", `/api/admin.users.remove`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * List users on a workspace
     * Documentation: https://api.slack.com/methods/admin.users.list
     * @param options Request options.
     */
    async getUsers(options) {
        const { headers, errorStrategy, userId, ...queryParams } = options;
        const customParams = { userId };
        const request = new Request("GET", constructUrl(`/api/admin.users.list`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Invite a user to a workspace.
     * Documentation: https://api.slack.com/methods/admin.users.invite
     * @param options Request options.
     */
    async inviteUser(options) {
        const { body, headers, errorStrategy, userId } = options;
        const customParams = { userId };
        const channel_ids = body.channel_ids && body.channel_ids.join();
        const requestBody = { ...body, channel_ids };
        const request = new Request("POST", `/api/admin.users.invite`, constructHeaders(body, headers, customParams), JSON.stringify(requestBody));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Add an Enterprise user to a workspace.
     * Documentation: https://api.slack.com/methods/admin.users.assign
     * @param options Request options.
     */
    async assignUser(options) {
        const { body, headers, errorStrategy, userId } = options;
        const customParams = { userId };
        const channel_ids = body.channel_ids && body.channel_ids.join();
        const requestBody = { ...body, channel_ids };
        const request = new Request("POST", `/api/admin.users.assign`, constructHeaders(body, headers, customParams), JSON.stringify(requestBody));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ViewGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Update an existing view.
     * Documentation: https://api.slack.com/methods/views.update
     * @param options Request options.
     */
    async updateView(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", constructUrl(`/api/views.update`, queryParams), constructHeaders(undefined, { ...headers, "Content-Type": "application/x-www-form-urlencoded" }, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Push a view onto the stack of a root view.
     * Documentation: https://api.slack.com/methods/views.push
     * @param options Request options.
     */
    async pushView(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", constructUrl(`/api/views.push`, queryParams), constructHeaders(undefined, { ...headers, "Content-Type": "application/x-www-form-urlencoded" }, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Publish a static view for a User.
     * Documentation: https://api.slack.com/methods/views.publish
     * @param options Request options.
     */
    async publishView(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/api/views.publish`, queryParams), constructHeaders(undefined, { ...headers, "Content-Type": "application/x-www-form-urlencoded" }));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Open a view for a user.
     * Documentation: https://api.slack.com/methods/views.open
     * @param options Request options.
     */
    async openView(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", constructUrl(`/api/views.open`, queryParams), constructHeaders(undefined, { ...headers, "Content-Type": "application/x-www-form-urlencoded" }, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class UserGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Profile = new UserProfileGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Find a user with an email address.
     * Documentation: https://api.slack.com/methods/users.lookupByEmail
     * @param options Request options.
     */
    async getUserByEmail(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/users.lookupByEmail`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Lists all users in a Slack team.
     * Documentation: https://api.slack.com/methods/users.list
     * @param options Request options.
     */
    async getUsers(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/users.list`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Gets information about a user.
     * Documentation: https://api.slack.com/methods/users.info
     * @param options Request options.
     */
    async getInfo(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/users.info`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get a user's identity.
     * Documentation: https://api.slack.com/methods/users.identity
     * @param options Request options.
     */
    async getIdentity(options) {
        const { headers, errorStrategy, userId } = options !== null && options !== void 0 ? options : {};
        const customParams = { userId };
        const request = new Request("GET", `/api/users.identity`, constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * List conversations the calling user may access.
     * Documentation: https://api.slack.com/methods/users.conversations
     * @param options Request options.
     */
    async getConversations(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/users.conversations`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Gets user presence information.
     * Documentation: https://api.slack.com/methods/users.getPresence
     * @param options Request options.
     */
    async getPresence(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/users.getPresence`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Manually sets user presence.
     * Documentation: https://api.slack.com/methods/users.setPresence
     * @param options Request options.
     */
    async setPresence(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/users.setPresence`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class UserProfileGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Set the profile information for a user.
     * Documentation: https://api.slack.com/methods/users.profile.set
     * @param options Request options.
     */
    async setProfile(options) {
        const { body, headers, errorStrategy, userId } = options;
        const customParams = { userId };
        const request = new Request("POST", `/api/users.profile.set`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Retrieves a user's profile information.
     * Documentation: https://api.slack.com/methods/users.profile.get
     * @param options Request options.
     */
    async getProfile(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/users.profile.get`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RemindersGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Lists all reminders created by or for a given user.
     * Documentation: https://api.slack.com/methods/reminders.list
     * @param options Request options.
     */
    async getReminders(options) {
        const { headers, errorStrategy, userId, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const customParams = { userId };
        const request = new Request("GET", constructUrl(`/api/reminders.list`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Gets information about a reminder.
     * Documentation: https://api.slack.com/methods/reminders.info
     * @param options Request options.
     */
    async getInfo(options) {
        const { headers, errorStrategy, userId, ...queryParams } = options;
        const customParams = { userId };
        const request = new Request("GET", constructUrl(`/api/reminders.info`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Deletes a reminder.
     * Documentation: https://api.slack.com/methods/reminders.delete
     * @param options Request options.
     */
    async deleteReminder(options) {
        const { body, headers, errorStrategy, userId } = options;
        const customParams = { userId };
        const request = new Request("POST", `/api/reminders.delete`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Marks a reminder as complete.
     * Documentation: https://api.slack.com/methods/reminders.complete
     * @param options Request options.
     */
    async completeReminder(options) {
        const { body, headers, errorStrategy, userId } = options;
        const customParams = { userId };
        const request = new Request("POST", `/api/reminders.complete`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Creates a reminder.
     * Documentation: https://api.slack.com/methods/reminders.add
     * @param options Request options.
     */
    async addReminder(options) {
        const { body, headers, errorStrategy, userId } = options;
        const customParams = { userId };
        const request = new Request("POST", `/api/reminders.add`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class PinsGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Un-pins an item from a channel.
     * Documentation: https://api.slack.com/methods/pins.remove
     * @param options Request options.
     */
    async removePin(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/pins.remove`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Lists items pinned to a channel.
     * Documentation: https://api.slack.com/methods/pins.list
     * @param options Request options.
     */
    async getPins(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/pins.list`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Pins an item to a channel.
     * Documentation: https://api.slack.com/methods/pins.add
     * @param options Request options.
     */
    async addPin(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/pins.add`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class BotGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Gets information about a bot user.
     * Documentation: https://api.slack.com/methods/bots.info
     * @param options Request options.
     */
    async getInfo(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/bots.info`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ChatGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Deletes a message.
     * Documentation: https://api.slack.com/methods/chat.delete
     * @param options Request options.
     */
    async deleteMessage(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/chat.delete`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Deletes a pending scheduled message from the queue.
     * Documentation: https://api.slack.com/methods/chat.deleteScheduledMessage
     * @param options Request options.
     */
    async deleteScheduledMessage(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/chat.deleteScheduledMessage`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Retrieve a permalink URL for a specific extant message
     * Documentation: https://api.slack.com/methods/chat.getPermalink
     * @param options Request options.
     */
    async getPermalink(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/chat.getPermalink`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Share a me message into a channel.
     * Documentation: https://api.slack.com/methods/chat.meMessage
     * @param options Request options.
     */
    async postMeMessage(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/chat.meMessage`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Sends an ephemeral message to a user in a channel.
     * Documentation: https://api.slack.com/methods/chat.postEphemeral
     * @param options Request options.
     */
    async postEphemeralMessage(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/chat.postEphemeral`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Sends a message to a channel.
     * Documentation: https://api.slack.com/methods/chat.postMessage
     * @param options Request options.
     */
    async postMessage(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/chat.postMessage`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Schedules a message to be sent to a channel.
     * Documentation: https://api.slack.com/methods/chat.scheduleMessage
     * @param options Request options.
     */
    async scheduleMessage(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/chat.scheduleMessage`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns a list of scheduled messages.
     * Documentation: https://api.slack.com/methods/chat.scheduledMessages.list
     * @param options Request options.
     */
    async getScheduledMessages(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/chat.scheduledMessages.list`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Provide custom unfurl behavior for user-posted URLs
     * Documentation: https://api.slack.com/methods/chat.unfurl
     * @param options Request options.
     */
    async unfurlMessage(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/chat.unfurl`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Updates a message.
     * Documentation: https://api.slack.com/methods/chat.update
     * @param options Request options.
     */
    async updateMessage(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/chat.update`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ConversationGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Archives a conversation.
     * Documentation: https://api.slack.com/methods/conversations.archive
     * @param options Request options.
     */
    async archiveConversation(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/conversations.archive`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Closes a direct message or multi-person direct message.
     * Documentation: https://api.slack.com/methods/conversations.close
     * @param options Request options.
     */
    async closeConversation(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/conversations.close`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Initiates a public or private channel-based conversation
     * Documentation: https://api.slack.com/methods/conversations.create
     * @param options Request options.
     */
    async createConversation(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/conversations.create`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Fetches a conversation's history of messages and events.
     * Documentation: https://api.slack.com/methods/conversations.history
     * @param options Request options.
     */
    async getHistory(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/conversations.history`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Retrieve information about a conversation.
     * Documentation: https://api.slack.com/methods/conversations.info
     * @param options Request options.
     */
    async getInfo(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/conversations.info`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Invites users to a channel.
     * Documentation: https://api.slack.com/methods/conversations.invite
     * @param options Request options.
     */
    async inviteUser(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/conversations.invite`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Joins an existing conversation.
     * Documentation: https://api.slack.com/methods/conversations.join
     * @param options Request options.
     */
    async joinConversation(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/conversations.join`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Removes a user from a conversation.
     * Documentation: https://api.slack.com/methods/conversations.kick
     * @param options Request options.
     */
    async kickUser(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/conversations.kick`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Leaves a conversation.
     * Documentation: https://api.slack.com/methods/conversations.leave
     * @param options Request options.
     */
    async leaveConversation(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/conversations.leave`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Lists all channels in a Slack team.
     * Documentation: https://api.slack.com/methods/conversations.list
     * @param options Request options.
     */
    async getConversations(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const customParams = { preferredAuth, userId };
        const types = queryParams.types && queryParams.types.join();
        const correctedParams = { ...queryParams, types };
        const request = new Request("GET", constructUrl(`/api/conversations.list`, correctedParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Retrieve members of a conversation.
     * Documentation: https://api.slack.com/methods/conversations.members
     * @param options Request options.
     */
    async getMembers(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/conversations.members`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Opens or resumes a direct message or multi-person direct message.
     * Documentation: https://api.slack.com/methods/conversations.open
     * @param options Request options.
     */
    async openConversation(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/conversations.open`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Renames a conversation.
     * Documentation: https://api.slack.com/methods/conversations.rename
     * @param options Request options.
     */
    async renameConversation(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/conversations.rename`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Retrieve a thread of messages posted to a conversation
     * Documentation: https://api.slack.com/methods/conversations.replies
     * @param options Request options.
     */
    async getReplies(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/conversations.replies`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Sets the purpose for a conversation.
     * Documentation: https://api.slack.com/methods/conversations.setPurpose
     * @param options Request options.
     */
    async setPurpose(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/conversations.setPurpose`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Sets the topic for a conversation.
     * Documentation: https://api.slack.com/methods/conversations.setTopic
     * @param options Request options.
     */
    async setTopic(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/conversations.setTopic`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Reverses conversation archival.
     * Documentation: https://api.slack.com/methods/conversations.unarchive
     * @param options Request options.
     */
    async unarchiveConversation(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/conversations.unarchive`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class DialogGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Open a dialog with a user
     * Documentation: https://api.slack.com/methods/dialog.open
     * @param options Request options.
     */
    async openDialog(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/dialog.open`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class DndGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Ends the current user's Do Not Disturb session immediately.
     * Documentation: https://api.slack.com/methods/dnd.endDnd
     * @param options Request options.
     */
    async endDnd(options) {
        const { headers, errorStrategy, userId } = options !== null && options !== void 0 ? options : {};
        const customParams = { userId };
        const request = new Request("POST", `/api/dnd.endDnd`, constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Ends the current user's snooze mode immediately.
     * Documentation: https://api.slack.com/methods/dnd.endSnooze
     * @param options Request options.
     */
    async endSnooze(options) {
        const { headers, errorStrategy, userId } = options !== null && options !== void 0 ? options : {};
        const customParams = { userId };
        const request = new Request("POST", `/api/dnd.endSnooze`, constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Retrieves a user's current Do Not Disturb status.
     * Documentation: https://api.slack.com/methods/dnd.info
     * @param options Request options.
     */
    async getInfo(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/dnd.info`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Turns on Do Not Disturb mode for the current user, or changes its duration.
     * Documentation: https://api.slack.com/methods/dnd.setSnooze
     * @param options Request options.
     */
    async setSnooze(options) {
        const { headers, errorStrategy, userId, ...queryParams } = options;
        const customParams = { userId };
        const request = new Request("GET", constructUrl(`/api/dnd.setSnooze`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Retrieves the Do Not Disturb status for up to 50 users on a team.
     * Documentation: https://api.slack.com/methods/dnd.teamInfo
     * @param options Request options.
     */
    async getTeamInfo(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/dnd.teamInfo`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class EmojiGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Lists custom emoji for a team.
     * Documentation: https://api.slack.com/methods/emoji.list
     * @param options Request options.
     */
    async getEmojis(options) {
        const { headers, errorStrategy, preferredAuth, userId } = options !== null && options !== void 0 ? options : {};
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", `/api/emoji.list`, constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class FileGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Comment = new FileCommentGroup(implementation, this.getGlobalErrorStrategy);
        this.PublicUrl = new FilePublicUrlGroup(implementation, this.getGlobalErrorStrategy);
        this.Remote = new FileRemoteGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Deletes a file.
     * Documentation: https://api.slack.com/methods/files.delete
     * @param options Request options.
     */
    async deleteFile(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/files.delete`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Gets information about a file.
     * Documentation: https://api.slack.com/methods/files.info
     * @param options Request options.
     */
    async getInfo(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/files.info`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * List for a team, in a channel, or from a user with applied filters.
     * Documentation: https://api.slack.com/methods/files.list
     * @param options Request options.
     */
    async getFiles(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/files.list`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Uploads or creates a file.
     * Documentation: https://api.slack.com/methods/files.upload
     * @param options Request options.
     */
    async uploadFile(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        let request;
        if (body.content) {
            request = new Request("GET", `/api/files.upload`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        }
        else {
            request = new Request("POST", `/api/files.upload`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        }
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class FileCommentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Deletes an existing comment on a file.
     * Documentation: https://api.slack.com/methods/files.comments.delete
     * @param options Request options.
     */
    async deleteComment(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/files.comments.delete`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class FilePublicUrlGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Revokes public/external sharing access for a file
     * Documentation: https://api.slack.com/methods/files.revokePublicURL
     * @param options Request options.
     */
    async revokePublicUrl(options) {
        const { body, headers, errorStrategy, userId } = options;
        const customParams = { userId };
        const request = new Request("POST", `/api/files.revokePublicURL`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Enables a file for public/external sharing.
     * Documentation: https://api.slack.com/methods/files.sharedPublicURL
     * @param options Request options.
     */
    async createPublicUrl(options) {
        const { body, headers, errorStrategy, userId } = options;
        const customParams = { userId };
        const request = new Request("POST", `/api/files.sharedPublicURL`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class FileRemoteGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Adds a file from a remote service
     * Documentation: https://api.slack.com/methods/files.remote.add
     * @param options Request options.
     */
    async addFile(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/api/files.remote.add`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Retrieve information about a remote file added to Slack
     * Documentation: https://api.slack.com/methods/files.remote.info
     * @param options Request options.
     */
    async getInfo(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/files.remote.info`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Retrieve information about a remote file added to Slack
     * Documentation: https://api.slack.com/methods/files.remote.list
     * @param options Request options.
     */
    async getFiles(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/files.remote.list`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Remove a remote file.
     * Documentation: https://api.slack.com/methods/files.remote.remove
     * @param options Request options.
     */
    async removeFile(options) {
        const { headers, errorStrategy, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const request = new Request("GET", constructUrl(`/api/files.remote.remove`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Share a remote file into a channel.
     * Documentation: https://api.slack.com/methods/files.remote.share
     * @param options Request options.
     */
    async shareFile(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/files.remote.share`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Updates an existing remote file.
     * Documentation: https://api.slack.com/methods/files.remote.update
     * @param options Request options.
     */
    async updateFile(options) {
        const { headers, errorStrategy, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const request = new Request("GET", constructUrl(`/api/files.remote.update`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ReactionGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Adds a reaction to an item.
     * Documentation: https://api.slack.com/methods/reactions.add
     * @param options Request options.
     */
    async addReaction(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/reactions.add`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Gets reactions for an item.
     * Documentation: https://api.slack.com/methods/reactions.get
     * @param options Request options.
     */
    async getReaction(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/reactions.get`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Lists reactions made by a user.
     * Documentation: https://api.slack.com/methods/reactions.list
     * @param options Request options.
     */
    async getReactions(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/reactions.list`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Removes a reaction from an item.
     * Documentation: https://api.slack.com/methods/reactions.remove
     * @param options Request options.
     */
    async removeReaction(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/reactions.remove`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class SearchGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Searches for messages matching a query.
     * Documentation: https://api.slack.com/methods/search.messages
     * @param options Request options.
     */
    async searchMessages(options) {
        const { headers, errorStrategy, userId, ...queryParams } = options;
        const customParams = { userId };
        const request = new Request("GET", constructUrl(`/api/search.messages`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class TeamGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Profile = new TeamProfileGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Gets the access logs for the current team.
     * Documentation: https://api.slack.com/methods/team.accessLogs
     * @param options Request options.
     */
    async getAccessLogs(options) {
        const { headers, errorStrategy, userId, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const customParams = { userId };
        const request = new Request("GET", constructUrl(`/api/team.accessLogs`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Gets billable users information for the current team.
     * Documentation: https://api.slack.com/methods/team.billableInfo
     * @param options Request options.
     */
    async getBillableInfo(options) {
        const { headers, errorStrategy, userId, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const customParams = { userId };
        const request = new Request("GET", constructUrl(`/api/team.billableInfo`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Gets information about the current team.
     * Documentation: https://api.slack.com/methods/team.info
     * @param options Request options.
     */
    async getInfo(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/team.info`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Gets the integration logs for the current team.
     * Documentation: https://api.slack.com/methods/team.integrationLogs
     * @param options Request options.
     */
    async getIntegrationLogs(options) {
        const { headers, errorStrategy, userId, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const customParams = { userId };
        const request = new Request("GET", constructUrl(`/api/team.integrationLogs`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class TeamProfileGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Retrieve a team's profile.
     * Documentation: https://api.slack.com/methods/team.profile.get
     * @param options Request options.
     */
    async getProfile(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/team.profile.get`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class UserGroupGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.User = new UserGroupUserGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Create a User Group
     * Documentation: https://api.slack.com/methods/usergroups.create
     * @param options Request options.
     */
    async createUserGroup(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/usergroups.create`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Disable an existing User Group
     * Documentation: https://api.slack.com/methods/usergroups.disable
     * @param options Request options.
     */
    async disableUserGroup(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/usergroups.disable`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Enable a User Group
     * Documentation: https://api.slack.com/methods/usergroups.enable
     * @param options Request options.
     */
    async enableUserGroup(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/usergroups.enable`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * List all User Groups for a team
     * Documentation: https://api.slack.com/methods/usergroups.list
     * @param options Request options.
     */
    async getUserGroups(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/usergroups.list`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update an existing User Group
     * Documentation: https://api.slack.com/methods/usergroups.update
     * @param options Request options.
     */
    async updateUserGroup(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/usergroups.update`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class UserGroupUserGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * List all users in a User Group
     * Documentation: https://api.slack.com/methods/usergroups.users.list
     * @param options Request options.
     */
    async getUsers(options) {
        const { headers, errorStrategy, preferredAuth, userId, ...queryParams } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("GET", constructUrl(`/api/usergroups.users.list`, queryParams), constructHeaders(undefined, headers, customParams));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update the list of users for a User Group
     * Documentation: https://api.slack.com/methods/usergroups.users.update
     * @param options Request options.
     */
    async updateUsers(options) {
        const { body, headers, errorStrategy, preferredAuth, userId } = options;
        const customParams = { preferredAuth, userId };
        const request = new Request("POST", `/api/usergroups.users.update`, constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ReplyGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Send message back to Slack using the response_url in the event payload.
     * Documentation: https://api.slack.com/interactivity/handling#message_responses
     * @param options Request options.
     */
    async postMessage(options) {
        const { body, headers, errorStrategy, responseUrl } = options;
        const customParams = { responseUrl };
        const request = new Request("POST", "/api/reply", constructHeaders(body, headers, customParams), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
//# sourceMappingURL=index.js.map