/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { UserIdOption } from "../../common";
import { DefsOkTrueAsResponse } from "../../definitions/DefsOkTrueAsResponse";
import { DefsOkFalseAsResponse } from "../../definitions/DefsOkFalseAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
export interface AdminSetRegularUserRequest extends HeadersOption, ErrorStrategyOption, UserIdOption {
    body: {
        /**
         * The ID (`T1234`) of the workspace.
         */
        team_id: string;
        /**
         * The ID of the user to designate as a regular user.
         */
        user_id: string;
    };
}
declare type AdminSetRegularUserResponseOKType = {
    ok: DefsOkTrueAsResponse;
    [x: string]: any;
};
export interface AdminSetRegularUserResponseOK extends AdminSetRegularUserResponseOKType {
}
declare type AdminSetRegularUserResponseErrorType = {
    ok: DefsOkFalseAsResponse;
    [x: string]: any;
};
export interface AdminSetRegularUserResponseError extends AdminSetRegularUserResponseErrorType {
}
export interface AdminSetOwnerUserRequest extends HeadersOption, ErrorStrategyOption, UserIdOption {
    body: {
        /**
         * The ID (`T1234`) of the workspace.
         */
        team_id: string;
        /**
         * Id of the user to promote to owner.
         */
        user_id: string;
    };
}
declare type AdminSetOwnerUserResponseOKType = {
    ok: DefsOkTrueAsResponse;
    [x: string]: any;
};
export interface AdminSetOwnerUserResponseOK extends AdminSetOwnerUserResponseOKType {
}
declare type AdminSetOwnerUserResponseErrorType = {
    ok: DefsOkFalseAsResponse;
    [x: string]: any;
};
export interface AdminSetOwnerUserResponseError extends AdminSetOwnerUserResponseErrorType {
}
export interface AdminSetUserExpirationRequest extends HeadersOption, ErrorStrategyOption, UserIdOption {
    body: {
        /**
         * The ID (`T1234`) of the workspace.
         */
        team_id: string;
        /**
         * The ID of the user to set an expiration for.
         */
        user_id: string;
        /**
         * Timestamp when guest account should be disabled.
         */
        expiration_ts: number;
    };
}
declare type AdminSetUserExpirationResponseOKType = {
    ok: DefsOkTrueAsResponse;
    [x: string]: any;
};
export interface AdminSetUserExpirationResponseOK extends AdminSetUserExpirationResponseOKType {
}
declare type AdminSetUserExpirationResponseErrorType = {
    ok: DefsOkFalseAsResponse;
    [x: string]: any;
};
export interface AdminSetUserExpirationResponseError extends AdminSetUserExpirationResponseErrorType {
}
export interface AdminSetAdminUserRequest extends HeadersOption, ErrorStrategyOption, UserIdOption {
    body: {
        /**
         * The ID (`T1234`) of the workspace.
         */
        team_id: string;
        /**
         * The ID of the user to designate as an admin.
         */
        user_id: string;
    };
}
declare type AdminSetAdminUserResponseOKType = {
    ok: DefsOkTrueAsResponse;
    [x: string]: any;
};
export interface AdminSetAdminUserResponseOK extends AdminSetAdminUserResponseOKType {
}
declare type AdminSetAdminUserResponseErrorType = {
    ok: DefsOkFalseAsResponse;
    [x: string]: any;
};
export interface AdminSetAdminUserResponseError extends AdminSetAdminUserResponseErrorType {
}
export interface AdminRemoveUserRequest extends HeadersOption, ErrorStrategyOption, UserIdOption {
    body: {
        /**
         * The ID (`T1234`) of the workspace.
         */
        team_id: string;
        /**
         * The ID of the user to remove.
         */
        user_id: string;
    };
}
declare type AdminRemoveUserResponseOKType = {
    ok: DefsOkTrueAsResponse;
    [x: string]: any;
};
export interface AdminRemoveUserResponseOK extends AdminRemoveUserResponseOKType {
}
declare type AdminRemoveUserResponseErrorType = {
    ok: DefsOkFalseAsResponse;
    [x: string]: any;
};
export interface AdminRemoveUserResponseError extends AdminRemoveUserResponseErrorType {
}
export interface AdminGetUsersRequest extends HeadersOption, ErrorStrategyOption, UserIdOption {
    /**
     * The ID (`T1234`) of the workspace.
     */
    team_id: string;
    /**
     * Set `cursor` to `next_cursor` returned by the previous call to list items in the next page.
     */
    cursor?: string;
    /**
     * Limit for how many users to be retrieved per page
     */
    limit?: number;
}
declare type AdminGetUsersResponseOKType = {
    ok: DefsOkTrueAsResponse;
    users: {
        id: string;
        email?: string;
        is_admin: boolean;
        is_owner: boolean;
        is_primary_owner: boolean;
        is_restricted: true;
        is_ultra_restricted: boolean;
        is_bot: boolean;
        expiration_ts?: number;
    }[];
    response_metadata: {
        next_cursor: string;
    };
};
export interface AdminGetUsersResponseOK extends AdminGetUsersResponseOKType {
}
declare type AdminGetUsersResponseErrorType = {
    ok: DefsOkFalseAsResponse;
    [x: string]: any;
};
export interface AdminGetUsersResponseError extends AdminGetUsersResponseErrorType {
}
export interface AdminInviteUserRequest extends HeadersOption, ErrorStrategyOption, UserIdOption {
    body: {
        /**
         * The ID (`T1234`) of the workspace.
         */
        team_id: string;
        /**
         * The email address of the person to invite.
         */
        email: string;
        /**
         * A comma-separated list of `channel_id`s for this user to join. At least one channel is required.
         */
        channel_ids: Array<string>;
        /**
         * An optional message to send to the user in the invite email.
         */
        custom_message?: string;
        /**
         * Full name of the user.
         */
        real_name?: string;
        /**
         * Allow this invite to be resent in the future if a user has not signed up yet. (default: false)
         */
        resend?: boolean;
        /**
         * Allow invited user to sign in via email and password. Only available for Enterprise Grid teams via admin invite.
         */
        email_password_policy_enabled?: boolean;
    };
}
declare type AdminInviteUserResponseOKType = {
    ok: DefsOkTrueAsResponse;
    [x: string]: any;
};
export interface AdminInviteUserResponseOK extends AdminInviteUserResponseOKType {
}
declare type AdminInviteUserResponseErrorType = {
    ok: DefsOkFalseAsResponse;
    [x: string]: any;
};
export interface AdminInviteUserResponseError extends AdminInviteUserResponseErrorType {
}
export interface AdminAssignUserRequest extends HeadersOption, ErrorStrategyOption, UserIdOption {
    body: {
        /**
         * The ID (`T1234`) of the workspace.
         */
        team_id: string;
        /**
         * The ID of the user to add to the workspace.
         */
        user_id: string;
        /**
         * True if user should be added to the workspace as a guest.
         */
        is_restricted?: boolean;
        /**
         * True if user should be added to the workspace as a single-channel guest.
         */
        is_ultra_restricted?: boolean;
        /**
         * Comma separated values of channel IDs to add user in the new workspace.
         */
        channel_ids?: Array<string>;
    };
}
declare type AdminAssignUserResponseOKType = {
    ok: DefsOkTrueAsResponse;
    [x: string]: any;
};
export interface AdminAssignUserResponseOK extends AdminAssignUserResponseOKType {
}
declare type AdminAssignUserResponseErrorType = {
    ok: DefsOkFalseAsResponse;
    [x: string]: any;
};
export interface AdminAssignUserResponseError extends AdminAssignUserResponseErrorType {
}
export {};
//# sourceMappingURL=users.d.ts.map