/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PreferredAuthOption } from "../common";
import { UserIdOption } from "../common";
import { DefsChannelAsResponse } from "../definitions/DefsChannelAsResponse";
import { DefsOkTrueAsResponse } from "../definitions/DefsOkTrueAsResponse";
import { DefsOkFalseAsResponse } from "../definitions/DefsOkFalseAsResponse";
import { DefsTsAsResponse } from "../definitions/DefsTsAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ObjsMessageAsResponse } from "../definitions/ObjsMessageAsResponse";
import { DefsChannelIdAsResponse } from "../definitions/DefsChannelIdAsResponse";
export interface DeleteChatMessageRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * Timestamp of the message to be deleted.
         */
        ts: string;
        /**
         * Channel containing the message to be deleted.
         */
        channel: string;
        /**
         * Pass true to delete the message as the authed user with `chat:write:user` scope. [Bot users](/bot-users) in this context are considered authed users. If unused or false, the message will be deleted with `chat:write:bot` scope.
         */
        as_user?: true;
    };
}
declare type DeleteChatMessageResponseOKType = {
    channel: DefsChannelAsResponse;
    ok: DefsOkTrueAsResponse;
    ts: DefsTsAsResponse;
};
export interface DeleteChatMessageResponseOK extends DeleteChatMessageResponseOKType {
}
declare type DeleteChatMessageResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "message_not_found" | "channel_not_found" | "cant_delete_message" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface DeleteChatMessageResponseError extends DeleteChatMessageResponseErrorType {
}
export interface DeleteChatScheduledMessageRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * Pass true to delete the message as the authed user with `chat:write:user` scope. [Bot users](/bot-users) in this context are considered authed users. If unused or false, the message will be deleted with `chat:write:bot` scope.
         */
        as_user?: true;
        /**
         * The channel the scheduled_message is posting to
         */
        channel: string;
        /**
         * `scheduled_message_id` returned from call to chat.scheduleMessage
         */
        scheduled_message_id: string;
    };
}
declare type DeleteChatScheduledMessageResponseOKType = {
    ok: DefsOkTrueAsResponse;
};
export interface DeleteChatScheduledMessageResponseOK extends DeleteChatScheduledMessageResponseOKType {
}
declare type DeleteChatScheduledMessageResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "invalid_scheduled_message_id" | "channel_not_found" | "bad_token" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "ekm_access_denied" | "missing_scope" | "invalid_arguments" | "invalid_arg_name" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface DeleteChatScheduledMessageResponseError extends DeleteChatScheduledMessageResponseErrorType {
}
export interface GetChatPermalinkRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * The ID of the conversation or channel containing the message
     */
    channel: string;
    /**
     * A message's `ts` value, uniquely identifying it within a channel
     */
    message_ts: string;
}
declare type GetChatPermalinkResponseOKType = {
    channel: DefsChannelAsResponse;
    ok: DefsOkTrueAsResponse;
    permalink: string;
};
export interface GetChatPermalinkResponseOK extends GetChatPermalinkResponseOKType {
}
declare type GetChatPermalinkResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "channel_not_found" | "message_not_found" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface GetChatPermalinkResponseError extends GetChatPermalinkResponseErrorType {
}
export interface PostChatMeMessageRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * Channel to send message to. Can be a public channel, private group or IM channel. Can be an encoded ID, or a name.
         */
        channel: string;
        /**
         * Text of the message to send.
         */
        text: string;
    };
}
declare type PostChatMeMessageResponseOKType = {
    channel?: DefsChannelAsResponse;
    ok: DefsOkTrueAsResponse;
    ts?: DefsTsAsResponse;
};
export interface PostChatMeMessageResponseOK extends PostChatMeMessageResponseOKType {
}
declare type PostChatMeMessageResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "channel_not_found" | "not_in_channel" | "is_archived" | "msg_too_long" | "no_text" | "rate_limited" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface PostChatMeMessageResponseError extends PostChatMeMessageResponseErrorType {
}
export interface PostChatEphemeralMessageRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * Pass true to post the message as the authed user. Defaults to true if the chat:write:bot scope is not included. Otherwise, defaults to false.
         */
        as_user?: true;
        /**
         * A JSON-based array of structured attachments, presented as a URL-encoded string.
         */
        attachments?: Record<string, any>[];
        /**
         * A JSON-based array of structured blocks, presented as a URL-encoded string.
         */
        blocks?: Record<string, any>[];
        /**
         * Channel, private group, or IM channel to send message to. Can be an encoded ID, or a name.
         */
        channel: string;
        /**
         * Emoji to use as the icon for this message. Overrides `icon_url`. Must be used in conjunction with `as_user` set to `false`, otherwise ignored. See [authorship](#authorship) below.
         */
        icon_emoji?: string;
        /**
         * URL to an image to use as the icon for this message. Must be used in conjunction with `as_user` set to false, otherwise ignored. See [authorship](#authorship) below.
         */
        icon_url?: string;
        /**
         * Find and link channel names and usernames.
         */
        link_names?: boolean;
        /**
         * Change how messages are treated. Defaults to `none`. See [below](#formatting).
         */
        parse?: string;
        /**
         * How this field works and whether it is required depends on other fields you use in your API call. [See below](#text_usage) for more detail.
         */
        text?: string;
        /**
         * Provide another message's `ts` value to post this message in a thread. Avoid using a reply's `ts` value; use its parent's value instead. Ephemeral messages in threads are only shown if there is already an active thread.
         */
        thread_ts?: string;
        /**
         * `id` of the user who will receive the ephemeral message. The user should be in the channel specified by the `channel` argument.
         */
        user: string;
        /**
         * Set your bot's user name. Must be used in conjunction with `as_user` set to false, otherwise ignored. See [authorship](#authorship) below.
         */
        username?: string;
    };
}
declare type PostChatEphemeralMessageResponseOKType = {
    message_ts: DefsTsAsResponse;
    ok: DefsOkTrueAsResponse;
};
export interface PostChatEphemeralMessageResponseOK extends PostChatEphemeralMessageResponseOKType {
}
declare type PostChatEphemeralMessageResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "channel_not_found" | "is_archived" | "msg_too_long" | "no_text" | "restricted_action" | "too_many_attachments" | "user_not_in_channel" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface PostChatEphemeralMessageResponseError extends PostChatEphemeralMessageResponseErrorType {
}
export interface PostChatMessageRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * Pass true to post the message as the authed user, instead of as a bot. Defaults to false. See [authorship](#authorship) below.
         */
        as_user?: true;
        /**
         * A JSON-based array of structured attachments, presented as a URL-encoded string.
         */
        attachments?: Record<string, any>[];
        /**
         * A JSON-based array of structured blocks, presented as a URL-encoded string.
         */
        blocks?: Record<string, any>[];
        /**
         * Channel, private group, or IM channel to send message to. Can be an encoded ID, or a name. See [below](#channels) for more details.
         */
        channel: string;
        /**
         * Emoji to use as the icon for this message. Overrides `icon_url`. Must be used in conjunction with `as_user` set to `false`, otherwise ignored. See [authorship](#authorship) below.
         */
        icon_emoji?: string;
        /**
         * URL to an image to use as the icon for this message. Must be used in conjunction with `as_user` set to false, otherwise ignored. See [authorship](#authorship) below.
         */
        icon_url?: string;
        /**
         * Find and link channel names and usernames.
         */
        link_names?: boolean;
        /**
         * JSON object with event_type and event_payload fields, presented as a URL-encoded string. Metadata you post to Slack is accessible to any app or user who is a member of that workspace.
         */
        metadata?: {
            event_type: string;
            event_payload: {
                id?: number;
                title?: string;
            };
        };
        /**
         * Change how messages are treated. Defaults to `none`. See [below](#formatting).
         */
        parse?: string;
        /**
         * Used in conjunction with `thread_ts` and indicates whether reply should be made visible to everyone in the channel or conversation. Defaults to `false`.
         */
        reply_broadcast?: boolean;
        /**
         * How this field works and whether it is required depends on other fields you use in your API call. [See below](#text_usage) for more detail.
         */
        text?: string;
        /**
         * Provide another message's `ts` value to make this message a reply. Avoid using a reply's `ts` value; use its parent instead.
         */
        thread_ts?: string;
        /**
         * Pass true to enable unfurling of primarily text-based content.
         */
        unfurl_links?: boolean;
        /**
         * Pass false to disable unfurling of media content.
         */
        unfurl_media?: boolean;
        /**
         * Set your bot's user name. Must be used in conjunction with `as_user` set to false, otherwise ignored. See [authorship](#authorship) below.
         */
        username?: string;
    };
}
declare type PostChatMessageResponseOKType = {
    channel: DefsChannelAsResponse;
    message: ObjsMessageAsResponse;
    ok: DefsOkTrueAsResponse;
    ts: DefsTsAsResponse;
};
export interface PostChatMessageResponseOK extends PostChatMessageResponseOKType {
}
declare type PostChatMessageResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "channel_not_found" | "not_in_channel" | "is_archived" | "msg_too_long" | "no_text" | "too_many_attachments" | "rate_limited" | "not_authed" | "invalid_auth" | "account_inactive" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type";
    ok: DefsOkFalseAsResponse;
};
export interface PostChatMessageResponseError extends PostChatMessageResponseErrorType {
}
export interface ScheduleChatMessageRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * Provide another message's `ts` value to make this message a reply. Avoid using a reply's `ts` value; use its parent instead.
         */
        thread_ts?: string;
        /**
         * A JSON-based array of structured blocks, presented as a URL-encoded string.
         */
        blocks?: Record<string, any>[];
        /**
         * A JSON-based array of structured attachments, presented as a URL-encoded string.
         */
        attachments?: Record<string, any>[];
        /**
         * Pass true to enable unfurling of primarily text-based content.
         */
        unfurl_links?: boolean;
        /**
         * Text of the message to send. See below for an explanation of [formatting](#formatting). This field is usually required, unless you're providing only `attachments` instead. Provide no more than 40,000 characters or [risk truncation](/changelog/2018-04-truncating-really-long-messages).
         */
        text?: string;
        /**
         * Find and link channel names and usernames.
         */
        link_names?: boolean;
        /**
         * Pass false to disable unfurling of media content.
         */
        unfurl_media?: boolean;
        /**
         * Change how messages are treated. Defaults to `none`. See [below](#formatting).
         */
        parse?: string;
        /**
         * Pass true to post the message as the authed user, instead of as a bot. Defaults to false. See [authorship](#authorship) below.
         */
        as_user?: true;
        /**
         * Unix EPOCH timestamp of time in future to send the message.
         */
        post_at: number;
        /**
         * Channel, private group, or DM channel to send message to. Can be an encoded ID, or a name. See [below](#channels) for more details.
         */
        channel: string;
        /**
         * Used in conjunction with `thread_ts` and indicates whether reply should be made visible to everyone in the channel or conversation. Defaults to `false`.
         */
        reply_broadcast?: boolean;
    };
}
declare type ScheduleChatMessageResponseOKType = {
    channel: DefsChannelAsResponse;
    message: ObjsMessageAsResponse;
    ok: DefsOkTrueAsResponse;
    post_at: number;
    scheduled_message_id: string;
};
export interface ScheduleChatMessageResponseOK extends ScheduleChatMessageResponseOKType {
}
declare type ScheduleChatMessageResponseErrorType = {
    error: "invalid_time" | "time_in_past" | "time_too_far" | "channel_not_found" | "not_in_channel" | "is_archived" | "msg_too_long" | "no_text" | "restricted_action" | "restricted_action_read_only_channel" | "restricted_action_thread_only_channel" | "restricted_action_non_threadable_channel" | "too_many_attachments" | "rate_limited" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "ekm_access_denied" | "missing_scope" | "invalid_arguments" | "invalid_arg_name" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface ScheduleChatMessageResponseError extends ScheduleChatMessageResponseErrorType {
}
export interface GetChatScheduledMessagesRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * The channel of the scheduled messages
     */
    channel?: string;
    /**
     * Encoded team id to list channels in, required if org token is used
     */
    team_id?: string;
    /**
     * A UNIX timestamp of the latest value in the time range
     */
    latest?: number;
    /**
     * A UNIX timestamp of the oldest value in the time range
     */
    oldest?: number;
    /**
     * Maximum number of original entries to return.
     */
    limit?: number;
    /**
     * For pagination purposes, this is the `cursor` value returned from a previous call to `chat.scheduledmessages.list` indicating where you want to start this call from.
     */
    cursor?: string;
}
declare type GetChatScheduledMessagesResponseOKType = {
    ok: DefsOkTrueAsResponse;
    response_metadata: {
        next_cursor: string;
    };
    scheduled_messages: Array<{
        channel_id: DefsChannelIdAsResponse;
        date_created: number;
        id: string;
        post_at: number;
        text?: string;
    }>;
};
export interface GetChatScheduledMessagesResponseOK extends GetChatScheduledMessagesResponseOKType {
}
declare type GetChatScheduledMessagesResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "invalid_channel" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "ekm_access_denied" | "missing_scope" | "invalid_arguments" | "invalid_arg_name" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface GetChatScheduledMessagesResponseError extends GetChatScheduledMessagesResponseErrorType {
}
export interface UnfurlChatMessageRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * Channel ID of the message. Both channel and ts must be provided together, or unfurl_id and source must be provided together.
         */
        channel?: string;
        /**
         * Timestamp of the message to add unfurl behavior to.
         */
        ts?: string;
        /**
         * The source of the link to unfurl. The source may either be composer, when the link is inside the message composer, or conversations_history, when the link has been posted to a conversation.
         */
        source?: string;
        /**
         * The ID of the link to unfurl. Both unfurl_id and source must be provided together, or channel and ts must be provided together.
         */
        unfurl_id?: string;
        /**
         * URL-encoded JSON map with keys set to URLs featured in the the message, pointing to their unfurl blocks or message attachments.
         */
        unfurls: Record<string, any>;
        /**
         * Provide a simply-formatted string to send as an ephemeral message to the user as invitation to authenticate further and enable full unfurling behavior
         */
        user_auth_message?: string;
        /**
         * Provide a JSON based array of structured blocks presented as URL-encoded string to send as an ephemeral message to the user as invitation to authenticate further and enable full unfurling behavior
         */
        user_auth_blocks?: Record<string, any>[];
        /**
         * Set to `true` or `1` to indicate the user must install your Slack app to trigger unfurls for this domain
         */
        user_auth_required?: boolean;
        /**
         * Send users to this custom URL where they will complete authentication in your app to fully trigger unfurling. Value should be properly URL-encoded.
         */
        user_auth_url?: string;
    };
}
declare type UnfurlChatMessageResponseOKType = {
    ok: DefsOkTrueAsResponse;
};
export interface UnfurlChatMessageResponseOK extends UnfurlChatMessageResponseOKType {
}
declare type UnfurlChatMessageResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "cannot_unfurl_url" | "cannot_find_service" | "missing_unfurls" | "cannot_prompt" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface UnfurlChatMessageResponseError extends UnfurlChatMessageResponseErrorType {
}
export interface UpdateChatMessageRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * A JSON-based array of structured attachments, presented as a URL-encoded string. This field is required when not presenting `text`. If you don't include this field, the message's previous `attachments` will be retained. To remove previous `attachments`, include an empty array for this field.
         */
        attachments?: Record<string, any>[];
        /**
         * A JSON-based array of [structured blocks](/block-kit/building), presented as a URL-encoded string. If you don't include this field, the message's previous `blocks` will be retained. To remove previous `blocks`, include an empty array for this field.
         */
        blocks?: Record<string, any>[];
        /**
         * Channel containing the message to be updated.
         */
        channel: string;
        /**
         * Find and link channel names and usernames. Defaults to `none`. If you do not specify a value for this field, the original value set for the message will be overwritten with the default, `none`.
         */
        link_names?: boolean;
        /**
         * Change how messages are treated. Defaults to `client`, unlike `chat.postMessage`. Accepts either `none` or `full`. If you do not specify a value for this field, the original value set for the message will be overwritten with the default, `client`.
         */
        parse?: string;
        /**
         * JSON object with event_type and event_payload fields, presented as a URL-encoded string. Metadata you post to Slack is accessible to any app or user who is a member of that workspace.
         */
        metadata?: {
            event_type: string;
            event_payload: {
                id?: number;
                title?: string;
            };
        };
        /**
         * New text for the message, using the [default formatting rules](/reference/surfaces/formatting). It's not required when presenting `blocks` or `attachments`.
         */
        text?: string;
        /**
         * Timestamp of the message to be updated.
         */
        ts: string;
    };
}
declare type UpdateChatMessageResponseOKType = {
    channel: DefsChannelAsResponse;
    message: ObjsMessageAsResponse;
    ok: DefsOkTrueAsResponse;
    text: string;
    ts: string;
};
export interface UpdateChatMessageResponseOK extends UpdateChatMessageResponseOKType {
}
declare type UpdateChatMessageResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "message_not_found" | "cant_update_message" | "channel_not_found" | "edit_window_closed" | "msg_too_long" | "too_many_attachments" | "rate_limited" | "no_text" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "request_timeout" | "invalid_json" | "json_not_object" | "upgrade_required" | "fatal_error" | "is_inactive";
    ok: DefsOkFalseAsResponse;
};
export interface UpdateChatMessageResponseError extends UpdateChatMessageResponseErrorType {
}
export {};
//# sourceMappingURL=chat.d.ts.map