/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PreferredAuthOption } from "../common";
import { UserIdOption } from "../common";
import { DefsOkTrueAsResponse } from "../definitions/DefsOkTrueAsResponse";
import { DefsOkFalseAsResponse } from "../definitions/DefsOkFalseAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ObjsConversationAsResponse } from "../definitions/ObjsConversationAsResponse";
import { ObjsMessageAsResponse } from "../definitions/ObjsMessageAsResponse";
import { DefsUserIdAsResponse } from "../definitions/DefsUserIdAsResponse";
import { DefsDmIdAsResponse } from "../definitions/DefsDmIdAsResponse";
import { DefsTsAsResponse } from "../definitions/DefsTsAsResponse";
import { ObjsReplyAsResponse } from "../definitions/ObjsReplyAsResponse";
export interface ArchiveConversationRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * ID of conversation to archive
         */
        channel: string;
    };
}
declare type ArchiveConversationResponseOKType = {
    ok: DefsOkTrueAsResponse;
};
export interface ArchiveConversationResponseOK extends ArchiveConversationResponseOKType {
}
declare type ArchiveConversationResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "method_not_supported_for_channel_type" | "missing_scope" | "not_supported" | "channel_not_found" | "already_archived" | "cant_archive_general" | "restricted_action" | "not_authed" | "invalid_auth" | "account_inactive" | "user_is_bot" | "user_is_restricted" | "user_is_ultra_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "team_added_to_org" | "missing_charset" | "superfluous_charset";
    needed?: string;
    ok: DefsOkFalseAsResponse;
    provided?: string;
};
export interface ArchiveConversationResponseError extends ArchiveConversationResponseErrorType {
}
export interface CloseConversationRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * Conversation to close.
         */
        channel: string;
    };
}
declare type CloseConversationResponseOKType = {
    already_closed?: boolean;
    no_op?: boolean;
    ok: DefsOkTrueAsResponse;
};
export interface CloseConversationResponseOK extends CloseConversationResponseOKType {
}
declare type CloseConversationResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "method_not_supported_for_channel_type" | "channel_not_found" | "user_does_not_own_channel" | "missing_scope" | "not_authed" | "invalid_auth" | "account_inactive" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
    needed?: string;
    ok: DefsOkFalseAsResponse;
    provided?: string;
};
export interface CloseConversationResponseError extends CloseConversationResponseErrorType {
}
export interface CreateConversationRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * Name of the public or private channel to create
         */
        name: string;
        /**
         * Create a private channel instead of a public one
         */
        is_private?: boolean;
        /**
         * Encoded team id to create the channel in, required if org token is used
         */
        team_id?: string;
    };
}
declare type CreateConversationResponseOKType = {
    channel: ObjsConversationAsResponse;
    ok: DefsOkTrueAsResponse;
};
export interface CreateConversationResponseOK extends CreateConversationResponseOKType {
}
declare type CreateConversationResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    detail?: string;
    error: "method_not_supported_for_channel_type" | "missing_scope" | "name_taken" | "restricted_action" | "no_channel" | "invalid_name_required" | "invalid_name_punctuation" | "invalid_name_maxlength" | "invalid_name_specials" | "invalid_name" | "not_authed" | "invalid_auth" | "account_inactive" | "user_is_bot" | "user_is_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
    needed?: string;
    ok: DefsOkFalseAsResponse;
    provided?: string;
};
export interface CreateConversationResponseError extends CreateConversationResponseErrorType {
}
export interface GetConversationHistoryRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * Conversation ID to fetch history for.
     */
    channel?: string;
    /**
     * End of time range of messages to include in results.
     */
    latest?: number;
    /**
     * Start of time range of messages to include in results.
     */
    oldest?: number;
    /**
     * Include messages with latest or oldest timestamp in results only when either timestamp is specified.
     */
    inclusive?: boolean;
    /**
     * The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the users list hasn't been reached.
     */
    limit?: number;
    /**
     * Paginate through collections of data by setting the `cursor` parameter to a `next_cursor` attribute returned by a previous request's `response_metadata`. Default value fetches the first "page" of the collection. See [pagination](/docs/pagination) for more detail.
     */
    cursor?: string;
}
declare type GetConversationHistoryResponseOKType = {
    channel_actions_count: number;
    channel_actions_ts: any;
    has_more: boolean;
    messages: Array<ObjsMessageAsResponse>;
    ok: DefsOkTrueAsResponse;
    pin_count: number;
    latest?: string;
    oldest?: string;
    response_metadata: {
        next_cursor: string;
    };
};
export interface GetConversationHistoryResponseOK extends GetConversationHistoryResponseOKType {
}
declare type GetConversationHistoryResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "missing_scope" | "channel_not_found" | "invalid_ts_latest" | "invalid_ts_oldest" | "not_authed" | "invalid_auth" | "account_inactive" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
    needed?: string;
    ok: DefsOkFalseAsResponse;
    provided?: string;
};
export interface GetConversationHistoryResponseError extends GetConversationHistoryResponseErrorType {
}
export interface GetConversationInfoRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * Conversation ID to learn more about
     */
    channel: string;
    /**
     * Set this to `true` to receive the locale for this conversation. Defaults to `false`
     */
    include_locale?: boolean;
    /**
     * Set to `true` to include the member count for the specified conversation. Defaults to `false`
     */
    include_num_members?: boolean;
}
declare type GetConversationInfoResponseOKType = {
    channel: ObjsConversationAsResponse;
    ok: DefsOkTrueAsResponse;
};
export interface GetConversationInfoResponseOK extends GetConversationInfoResponseOKType {
}
declare type GetConversationInfoResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "missing_scope" | "channel_not_found" | "team_added_to_org" | "not_authed" | "invalid_auth" | "account_inactive" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
    needed?: string;
    ok: DefsOkFalseAsResponse;
    provided?: string;
};
export interface GetConversationInfoResponseError extends GetConversationInfoResponseErrorType {
}
export interface InviteUserToConversationRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * The ID of the public or private channel to invite user(s) to.
         */
        channel: string;
        /**
         * A comma separated list of user IDs. Up to 1000 users may be listed.
         */
        users: string;
    };
}
declare type InviteUserToConversationResponseOKType = {
    channel: ObjsConversationAsResponse;
    ok: DefsOkTrueAsResponse;
};
export interface InviteUserToConversationResponseOK extends InviteUserToConversationResponseOKType {
}
declare type InviteUserToConversationResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error?: "method_not_supported_for_channel_type" | "missing_scope" | "channel_not_found" | "user_not_found" | "no_user" | "cant_invite_self" | "not_in_channel" | "already_in_channel" | "is_archived" | "cant_invite" | "too_many_users" | "ura_max_channels" | "not_authed" | "invalid_auth" | "account_inactive" | "user_is_bot" | "user_is_restricted" | "user_is_ultra_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "team_added_to_org" | "missing_charset" | "superfluous_charset";
    errors?: Array<{
        error: "method_not_supported_for_channel_type" | "missing_scope" | "channel_not_found" | "user_not_found" | "no_user" | "cant_invite_self" | "not_in_channel" | "already_in_channel" | "is_archived" | "cant_invite" | "too_many_users" | "ura_max_channels" | "not_authed" | "invalid_auth" | "account_inactive" | "user_is_bot" | "user_is_restricted" | "user_is_ultra_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "team_added_to_org" | "missing_charset" | "superfluous_charset";
        ok: DefsOkFalseAsResponse;
        user?: DefsUserIdAsResponse;
    }>;
    needed?: string;
    ok: DefsOkFalseAsResponse;
    provided?: string;
};
export interface InviteUserToConversationResponseError extends InviteUserToConversationResponseErrorType {
}
export interface JoinConversationRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * ID of conversation to join
         */
        channel: string;
    };
}
declare type JoinConversationResponseOKType = {
    channel: ObjsConversationAsResponse;
    ok: DefsOkTrueAsResponse;
    response_metadata?: {
        warnings?: Array<string>;
    };
    warning?: string;
};
export interface JoinConversationResponseOK extends JoinConversationResponseOKType {
}
declare type JoinConversationResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "method_not_supported_for_channel_type" | "missing_scope" | "channel_not_found" | "is_archived" | "not_authed" | "invalid_auth" | "account_inactive" | "user_is_bot" | "user_is_restricted" | "user_is_ultra_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "team_added_to_org" | "missing_charset" | "superfluous_charset";
    needed?: string;
    ok: DefsOkFalseAsResponse;
    provided?: string;
};
export interface JoinConversationResponseError extends JoinConversationResponseErrorType {
}
export interface KickUserFromConversationRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * ID of conversation to remove user from.
         */
        channel: string;
        /**
         * User ID to be removed.
         */
        user: string;
    };
}
declare type KickUserFromConversationResponseOKType = {
    ok: DefsOkTrueAsResponse;
};
export interface KickUserFromConversationResponseOK extends KickUserFromConversationResponseOKType {
}
declare type KickUserFromConversationResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "method_not_supported_for_channel_type" | "missing_scope" | "channel_not_found" | "user_not_found" | "cant_kick_self" | "not_in_channel" | "cant_kick_from_general" | "restricted_action" | "not_authed" | "invalid_auth" | "account_inactive" | "user_is_bot" | "user_is_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
    needed?: string;
    ok: DefsOkFalseAsResponse;
    provided?: string;
};
export interface KickUserFromConversationResponseError extends KickUserFromConversationResponseErrorType {
}
export interface LeaveConversationRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * Conversation to leave
         */
        channel: string;
    };
}
declare type LeaveConversationResponseOKType = {
    not_in_channel?: true;
    ok: DefsOkTrueAsResponse;
};
export interface LeaveConversationResponseOK extends LeaveConversationResponseOKType {
}
declare type LeaveConversationResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "method_not_supported_for_channel_type" | "last_member" | "missing_scope" | "channel_not_found" | "is_archived" | "cant_leave_general" | "not_authed" | "invalid_auth" | "account_inactive" | "user_is_bot" | "user_is_restricted" | "user_is_ultra_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "team_added_to_org" | "missing_charset" | "superfluous_charset";
    needed?: string;
    ok: DefsOkFalseAsResponse;
    provided?: string;
};
export interface LeaveConversationResponseError extends LeaveConversationResponseErrorType {
}
export interface GetConversationsRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * Set to `true` to exclude archived channels from the list
     */
    exclude_archived?: boolean;
    /**
     * Mix and match channel types by providing an array of any combination of `public_channel`, `private_channel`, `mpim`, `im`
     */
    types?: Array<"public_channel" | "private_channel" | "mpim" | "im">;
    /**
     * The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the list hasn't been reached. Must be an integer no larger than 1000.
     */
    limit?: number;
    /**
     * Paginate through collections of data by setting the `cursor` parameter to a `next_cursor` attribute returned by a previous request's `response_metadata`. Default value fetches the first "page" of the collection. See [pagination](/docs/pagination) for more detail.
     */
    cursor?: string;
    /**
     * Encoded team id to list channels in, required if token belongs to org-wide app
     */
    team_id?: string;
}
declare type GetConversationsResponseOKType = {
    channels: Array<ObjsConversationAsResponse>;
    ok: DefsOkTrueAsResponse;
    response_metadata?: {
        next_cursor: string;
    };
};
export interface GetConversationsResponseOK extends GetConversationsResponseOKType {
}
declare type GetConversationsResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "missing_scope" | "not_authed" | "invalid_auth" | "account_inactive" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
    needed?: string;
    ok: DefsOkFalseAsResponse;
    provided?: string;
};
export interface GetConversationsResponseError extends GetConversationsResponseErrorType {
}
export interface GetConversationMembersRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * ID of the conversation to retrieve members for
     */
    channel: string;
    /**
     * The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the users list hasn't been reached.
     */
    limit?: number;
    /**
     * Paginate through collections of data by setting the `cursor` parameter to a `next_cursor` attribute returned by a previous request's `response_metadata`. Default value fetches the first "page" of the collection. See [pagination](/docs/pagination) for more detail.
     */
    cursor?: string;
}
declare type GetConversationMembersResponseOKType = {
    members: Array<DefsUserIdAsResponse>;
    ok: DefsOkTrueAsResponse;
    response_metadata: {
        next_cursor: string;
    };
};
export interface GetConversationMembersResponseOK extends GetConversationMembersResponseOKType {
}
declare type GetConversationMembersResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "channel_not_found" | "invalid_limit" | "invalid_cursor" | "fetch_members_failed" | "not_authed" | "invalid_auth" | "account_inactive" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
    ok: DefsOkFalseAsResponse;
};
export interface GetConversationMembersResponseError extends GetConversationMembersResponseErrorType {
}
export interface OpenConversationRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * Resume a conversation by supplying an `im` or `mpim`'s ID. Or provide the `users` field instead.
         */
        channel?: string;
        /**
         * Comma separated lists of users. If only one user is included, this creates a 1:1 DM.  The ordering of the users is preserved whenever a multi-person direct message is returned. Supply a `channel` when not supplying `users`.
         */
        users?: string;
        /**
         * Boolean, indicates you want the full IM channel definition in the response.
         */
        return_im?: boolean;
    };
}
export interface OpenConversationResponseOK {
    already_open?: boolean;
    channel: ObjsConversationAsResponse & {
        created?: string;
        id: DefsDmIdAsResponse;
        is_im?: boolean;
        last_read?: DefsTsAsResponse;
        latest?: ObjsMessageAsResponse;
        unread_count?: number;
        unread_count_display?: number;
        user?: DefsUserIdAsResponse;
    };
    no_op?: boolean;
    ok: DefsOkTrueAsResponse;
}
export interface OpenConversationResponseError {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "method_not_supported_for_channel_type" | "user_not_found" | "user_not_visible" | "user_disabled" | "users_list_not_supplied" | "not_enough_users" | "too_many_users" | "invalid_user_combination" | "not_authed" | "invalid_auth" | "account_inactive" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "channel_not_found";
    ok: DefsOkFalseAsResponse;
}
export interface RenameConversationRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * ID of conversation to rename
         */
        channel: string;
        /**
         * New name for conversation.
         */
        name: string;
    };
}
declare type RenameConversationResponseOKType = {
    channel: ObjsConversationAsResponse;
    ok: DefsOkTrueAsResponse;
};
export interface RenameConversationResponseOK extends RenameConversationResponseOKType {
}
declare type RenameConversationResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "user_is_restricted" | "method_not_supported_for_channel_type" | "missing_scope" | "channel_not_found" | "not_in_channel" | "not_authorized" | "invalid_name" | "name_taken" | "invalid_name_required" | "invalid_name_punctuation" | "invalid_name_maxlength" | "invalid_name_specials" | "not_authed" | "invalid_auth" | "account_inactive" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
    needed?: string;
    ok: DefsOkFalseAsResponse;
    provided?: string;
};
export interface RenameConversationResponseError extends RenameConversationResponseErrorType {
}
export interface GetConversationRepliesRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * Conversation ID to fetch thread from.
     */
    channel?: string;
    /**
     * Unique identifier of a thread's parent message. `ts` must be the timestamp of an existing message with 0 or more replies. If there are no replies then just the single message referenced by `ts` will return - it is just an ordinary, unthreaded message.
     */
    ts?: number;
    /**
     * End of time range of messages to include in results.
     */
    latest?: number;
    /**
     * Start of time range of messages to include in results.
     */
    oldest?: number;
    /**
     * Include messages with latest or oldest timestamp in results only when either timestamp is specified.
     */
    inclusive?: boolean;
    /**
     * The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the users list hasn't been reached.
     */
    limit?: number;
    /**
     * Paginate through collections of data by setting the `cursor` parameter to a `next_cursor` attribute returned by a previous request's `response_metadata`. Default value fetches the first "page" of the collection. See [pagination](/docs/pagination) for more detail.
     */
    cursor?: string;
}
declare type GetConversationRepliesResponseOKType = {
    has_more?: boolean;
    response_metadata?: {
        next_cursor: string;
    };
    messages: Array<ObjsReplyAsResponse>;
    ok: DefsOkTrueAsResponse;
};
export interface GetConversationRepliesResponseOK extends GetConversationRepliesResponseOKType {
}
declare type GetConversationRepliesResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "missing_scope" | "channel_not_found" | "thread_not_found" | "not_authed" | "invalid_auth" | "account_inactive" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
    needed?: string;
    ok: DefsOkFalseAsResponse;
    provided?: string;
};
export interface GetConversationRepliesResponseError extends GetConversationRepliesResponseErrorType {
}
export interface SetConversationPurposeRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * Conversation to set the purpose of
         */
        channel: string;
        /**
         * A new, specialer purpose
         */
        purpose: string;
    };
}
declare type SetConversationPurposeResponseOKType = {
    channel: ObjsConversationAsResponse;
    ok: DefsOkTrueAsResponse;
};
export interface SetConversationPurposeResponseOK extends SetConversationPurposeResponseOKType {
}
declare type SetConversationPurposeResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "method_not_supported_for_channel_type" | "missing_scope" | "channel_not_found" | "not_in_channel" | "is_archived" | "too_long" | "user_is_restricted" | "not_authed" | "invalid_auth" | "account_inactive" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
    needed?: string;
    ok: DefsOkFalseAsResponse;
    provided?: string;
};
export interface SetConversationPurposeResponseError extends SetConversationPurposeResponseErrorType {
}
export interface SetConversationTopicRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * Conversation to set the topic of
         */
        channel: string;
        /**
         * The new topic string. Does not support formatting or linkification.
         */
        topic: string;
    };
}
declare type SetConversationTopicResponseOKType = {
    channel: ObjsConversationAsResponse;
    ok: DefsOkTrueAsResponse;
};
export interface SetConversationTopicResponseOK extends SetConversationTopicResponseOKType {
}
declare type SetConversationTopicResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "method_not_supported_for_channel_type" | "missing_scope" | "channel_not_found" | "not_in_channel" | "is_archived" | "too_long" | "user_is_restricted" | "not_authed" | "invalid_auth" | "account_inactive" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
    needed?: string;
    ok: DefsOkFalseAsResponse;
    provided?: string;
};
export interface SetConversationTopicResponseError extends SetConversationTopicResponseErrorType {
}
export interface UnarchiveConversationRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * ID of conversation to unarchive
         */
        channel: string;
    };
}
declare type UnarchiveConversationResponseOKType = {
    ok: DefsOkTrueAsResponse;
};
export interface UnarchiveConversationResponseOK extends UnarchiveConversationResponseOKType {
}
declare type UnarchiveConversationResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "method_not_supported_for_channel_type" | "missing_scope" | "channel_not_found" | "not_archived" | "not_authed" | "invalid_auth" | "account_inactive" | "user_is_bot" | "user_is_restricted" | "user_is_ultra_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "team_added_to_org" | "missing_charset" | "superfluous_charset";
    needed?: string;
    ok: DefsOkFalseAsResponse;
    provided?: string;
};
export interface UnarchiveConversationResponseError extends UnarchiveConversationResponseErrorType {
}
export {};
//# sourceMappingURL=conversation.d.ts.map