/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { UserIdOption } from "../common";
import { DefsOkTrueAsResponse } from "../definitions/DefsOkTrueAsResponse";
import { DefsOkFalseAsResponse } from "../definitions/DefsOkFalseAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { PreferredAuthOption } from "../common";
export interface EndDndRequest extends HeadersOption, ErrorStrategyOption, UserIdOption {
}
declare type EndDndResponseOKType = {
    ok: DefsOkTrueAsResponse;
};
export interface EndDndResponseOK extends EndDndResponseOKType {
}
declare type EndDndResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "unknown_error" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface EndDndResponseError extends EndDndResponseErrorType {
}
export interface EndDndSnoozeRequest extends HeadersOption, ErrorStrategyOption, UserIdOption {
}
declare type EndDndSnoozeResponseOKType = {
    dnd_enabled: boolean;
    next_dnd_end_ts: number;
    next_dnd_start_ts: number;
    ok: DefsOkTrueAsResponse;
    snooze_enabled: boolean;
};
export interface EndDndSnoozeResponseOK extends EndDndSnoozeResponseOKType {
}
declare type EndDndSnoozeResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "snooze_not_active" | "snooze_end_failed" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface EndDndSnoozeResponseError extends EndDndSnoozeResponseErrorType {
}
export interface GetDndInfoRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * User to fetch status for (defaults to current user)
     */
    user?: string;
}
declare type GetDndInfoResponseOKType = {
    dnd_enabled: boolean;
    next_dnd_end_ts: number;
    next_dnd_start_ts: number;
    ok: DefsOkTrueAsResponse;
    snooze_enabled?: boolean;
    snooze_endtime?: number;
    snooze_remaining?: number;
};
export interface GetDndInfoResponseOK extends GetDndInfoResponseOKType {
}
declare type GetDndInfoResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "user_not_found" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface GetDndInfoResponseError extends GetDndInfoResponseErrorType {
}
export interface SetDndSnoozeRequest extends HeadersOption, ErrorStrategyOption, UserIdOption {
    /**
     * Number of minutes, from now, to snooze until.
     */
    num_minutes: string;
}
declare type SetDndSnoozeResponseOKType = {
    ok: DefsOkTrueAsResponse;
    snooze_enabled: boolean;
    snooze_endtime: number;
    snooze_remaining: number;
};
export interface SetDndSnoozeResponseOK extends SetDndSnoozeResponseOKType {
}
declare type SetDndSnoozeResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "missing_duration" | "snooze_failed" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "too_long" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface SetDndSnoozeResponseError extends SetDndSnoozeResponseErrorType {
}
export interface GetDndTeamInfoRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * Comma-separated list of users to fetch Do Not Disturb status for
     */
    users: string;
}
declare type GetDndTeamInfoResponseOKType = {
    cached?: boolean;
    ok: DefsOkTrueAsResponse;
    users: {
        [x: string]: {
            dnd_enabled: boolean;
            next_dnd_start_ts: number;
            next_dnd_end_ts: number;
        };
    };
};
export interface GetDndTeamInfoResponseOK extends GetDndTeamInfoResponseOKType {
}
declare type GetDndTeamInfoResponseErrorType = {
    error: "no_users_provided" | "not_authed" | "invalid_auth" | "account_inactive" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "request_timeout" | "upgrade_required";
    ok: DefsOkFalseAsResponse;
};
export interface GetDndTeamInfoResponseError extends GetDndTeamInfoResponseErrorType {
}
export {};
//# sourceMappingURL=dnd.d.ts.map