/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PreferredAuthOption } from "../common";
import { UserIdOption } from "../common";
import { DefsOkTrueAsResponse } from "../definitions/DefsOkTrueAsResponse";
import { DefsOkFalseAsResponse } from "../definitions/DefsOkFalseAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ObjsCommentsAsResponse } from "../definitions/ObjsCommentsAsResponse";
import { DefsUserIdAsResponse } from "../definitions/DefsUserIdAsResponse";
import { ObjsFileAsResponse } from "../definitions/ObjsFileAsResponse";
import { ObjsPagingAsResponse } from "../definitions/ObjsPagingAsResponse";
import { ObjsResponseMetadataAsResponse } from "../definitions/ObjsResponseMetadataAsResponse";
export interface DeleteFileRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * ID of file to delete.
         */
        file: string;
    };
}
declare type DeleteFileResponseOKType = {
    ok: DefsOkTrueAsResponse;
};
export interface DeleteFileResponseOK extends DeleteFileResponseOKType {
}
declare type DeleteFileResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "file_not_found" | "file_deleted" | "cant_delete_file" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
    ok: DefsOkFalseAsResponse;
};
export interface DeleteFileResponseError extends DeleteFileResponseErrorType {
}
export interface GetFileInfoRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * Number of items to return per page.
     */
    count?: string;
    /**
     * Parameter for pagination. File comments are paginated for a single file. Set `cursor` equal to the `next_cursor` attribute returned by the previous request's `response_metadata`. This parameter is optional, but pagination is mandatory: the default value simply fetches the first "page" of the collection of comments. See [pagination](/docs/pagination) for more details.
     */
    cursor?: string;
    /**
     * The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the list hasn't been reached.
     */
    limit?: number;
    /**
     * Specify a file by providing its ID.
     */
    file: string;
    /**
     * Page number of results to return.
     */
    page?: string;
}
export interface GetFileInfoResponseOK {
    comments: ObjsCommentsAsResponse;
    content_highlight_html: string;
    content_highlight_css: string;
    editor?: DefsUserIdAsResponse;
    is_truncated: boolean;
    content: string;
    file: ObjsFileAsResponse;
    ok: DefsOkTrueAsResponse;
    paging?: ObjsPagingAsResponse;
    response_metadata?: ObjsResponseMetadataAsResponse;
}
export interface GetFileInfoResponseError {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "file_not_found" | "file_deleted" | "timezone_count_failed" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
    ok: DefsOkFalseAsResponse;
}
export interface GetFilesRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * Filter files created by a single user.
     */
    user?: string;
    /**
     * Filter files appearing in a specific channel, indicated by its ID.
     */
    channel?: string;
    /**
     * Filter files created after this timestamp (inclusive).
     */
    ts_from?: number;
    /**
     * Filter files created before this timestamp (inclusive).
     */
    ts_to?: number;
    /**
     * Filter files by type ([see below](#file_types)). You can pass multiple values in the types argument, like `types=spaces,snippets`.The default value is `all`, which does not filter the list.
     */
    types?: string;
    count?: string;
    page?: string;
    /**
     * Show truncated file info for files hidden due to being too old, and the team who owns the file being over the file limit.
     */
    show_files_hidden_by_limit?: boolean;
}
declare type GetFilesResponseOKType = {
    files: Array<ObjsFileAsResponse>;
    ok: DefsOkTrueAsResponse;
    paging: ObjsPagingAsResponse;
};
export interface GetFilesResponseOK extends GetFilesResponseOKType {
}
declare type GetFilesResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "user_not_found" | "unknown_type" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "user_is_bot" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
    ok: DefsOkFalseAsResponse;
};
export interface GetFilesResponseError extends GetFilesResponseErrorType {
}
export interface UploadFileRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * Comma-separated list of channel names or IDs where the file will be shared.
         */
        channels?: string;
        /**
         * Title of file.
         */
        title?: string;
        /**
         * The message text introducing the file in specified `channels`.
         */
        initial_comment?: string;
        /**
         * A [file type](/types/file#file_types) identifier.
         */
        filetype?: string;
        /**
         * Filename of file.
         */
        filename?: string;
        /**
         * File contents via a POST variable. If omitting this parameter, you must provide a `file`.
         */
        content?: string;
        /**
         * File contents via `multipart/form-data`. If omitting this parameter, you must submit `content`.
         */
        file?: ArrayBuffer | string;
        /**
         * Provide another message's `ts` value to upload this file as a reply. Never use a reply's `ts` value; use its parent instead.
         */
        thread_ts?: number;
    };
}
export interface UploadFileResponseOK {
    file: ObjsFileAsResponse;
    ok: DefsOkTrueAsResponse;
}
export interface UploadFileResponseError {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "posting_to_general_channel_denied" | "invalid_channel" | "file_uploads_disabled" | "file_uploads_except_images_disabled" | "storage_limit_reached" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
    ok: DefsOkFalseAsResponse;
}
export {};
//# sourceMappingURL=file.d.ts.map