/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { DefsOkTrueAsResponse } from "../../definitions/DefsOkTrueAsResponse";
import { ObjsFileAsResponse } from "../../definitions/ObjsFileAsResponse";
import { DefsOkFalseAsResponse } from "../../definitions/DefsOkFalseAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { PreferredAuthOption } from "../../common";
import { UserIdOption } from "../../common";
export interface AddRemoteFileRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Creator defined GUID for the file.
     */
    external_id: string;
    /**
     * Title of the file being shared.
     */
    title: string;
    /**
     * type of file
     */
    filetype?: string;
    /**
     * URL of the remote file.
     */
    external_url: string;
    /**
     * Preview of the document via `multipart/form-data`.
     */
    preview_image?: string;
    /**
     * A text file (txt, pdf, doc, etc.) containing textual search terms that are used to improve discovery of the remote file.
     */
    indexable_file_contents?: string;
}
declare type AddRemoteFileResponseOKType = {
    ok: DefsOkTrueAsResponse;
    file?: ObjsFileAsResponse;
    [x: string]: any;
};
export interface AddRemoteFileResponseOK extends AddRemoteFileResponseOKType {
}
declare type AddRemoteFileResponseErrorType = {
    ok: DefsOkFalseAsResponse;
    [x: string]: any;
};
export interface AddRemoteFileResponseError extends AddRemoteFileResponseErrorType {
}
export interface GetRemoteFileInfoRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * Specify a file by providing its ID.
     */
    file?: string;
    /**
     * Creator defined GUID for the file.
     */
    external_id?: string;
}
declare type GetRemoteFileInfoResponseOKType = {
    ok: DefsOkTrueAsResponse;
    [x: string]: any;
};
export interface GetRemoteFileInfoResponseOK extends GetRemoteFileInfoResponseOKType {
}
declare type GetRemoteFileInfoResponseErrorType = {
    ok: DefsOkFalseAsResponse;
    [x: string]: any;
};
export interface GetRemoteFileInfoResponseError extends GetRemoteFileInfoResponseErrorType {
}
export interface GetRemoteFilesRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * Filter files appearing in a specific channel, indicated by its ID.
     */
    channel?: string;
    /**
     * Filter files created after this timestamp (inclusive).
     */
    ts_from?: number;
    /**
     * Filter files created before this timestamp (inclusive).
     */
    ts_to?: number;
    /**
     * The maximum number of items to return.
     */
    limit?: number;
    /**
     * Paginate through collections of data by setting the `cursor` parameter to a `next_cursor` attribute returned by a previous request's `response_metadata`. Default value fetches the first "page" of the collection. See [pagination](/docs/pagination) for more detail.
     */
    cursor?: string;
}
declare type GetRemoteFilesResponseOKType = {
    ok: DefsOkTrueAsResponse;
    [x: string]: any;
};
export interface GetRemoteFilesResponseOK extends GetRemoteFilesResponseOKType {
}
declare type GetRemoteFilesResponseErrorType = {
    ok: DefsOkFalseAsResponse;
    [x: string]: any;
};
export interface GetRemoteFilesResponseError extends GetRemoteFilesResponseErrorType {
}
export interface RemoveRemoteFileRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Specify a file by providing its ID.
     */
    file?: string;
    /**
     * Creator defined GUID for the file.
     */
    external_id?: string;
}
declare type RemoveRemoteFileResponseOKType = {
    ok: DefsOkTrueAsResponse;
    [x: string]: any;
};
export interface RemoveRemoteFileResponseOK extends RemoveRemoteFileResponseOKType {
}
declare type RemoveRemoteFileResponseErrorType = {
    ok: DefsOkFalseAsResponse;
    [x: string]: any;
};
export interface RemoveRemoteFileResponseError extends RemoveRemoteFileResponseErrorType {
}
export interface ShareRemoteFileRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * Specify a file registered with Slack by providing its ID. Either this field or `external_id` or both are required.
     */
    file?: string;
    /**
     * The globally unique identifier (GUID) for the file, as set by the app registering the file with Slack.  Either this field or `file` or both are required.
     */
    external_id?: string;
    /**
     * Comma-separated list of channel IDs where the file will be shared.
     */
    channels?: string;
}
declare type ShareRemoteFileResponseOKType = {
    ok: DefsOkTrueAsResponse;
    [x: string]: any;
};
export interface ShareRemoteFileResponseOK extends ShareRemoteFileResponseOKType {
}
declare type ShareRemoteFileResponseErrorType = {
    ok: DefsOkFalseAsResponse;
    [x: string]: any;
};
export interface ShareRemoteFileResponseError extends ShareRemoteFileResponseErrorType {
}
export interface UpdateRemoteFileRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Specify a file by providing its ID.
     */
    file?: string;
    /**
     * Creator defined GUID for the file.
     */
    external_id?: string;
    /**
     * Title of the file being shared.
     */
    title?: string;
    /**
     * type of file
     */
    filetype?: string;
    /**
     * URL of the remote file.
     */
    external_url?: string;
    /**
     * Preview of the document via `multipart/form-data`.
     */
    preview_image?: string;
    /**
     * File containing contents that can be used to improve searchability for the remote file.
     */
    indexable_file_contents?: string;
}
declare type UpdateRemoteFileResponseOKType = {
    ok: DefsOkTrueAsResponse;
    [x: string]: any;
};
export interface UpdateRemoteFileResponseOK extends UpdateRemoteFileResponseOKType {
}
declare type UpdateRemoteFileResponseErrorType = {
    ok: DefsOkFalseAsResponse;
    [x: string]: any;
};
export interface UpdateRemoteFileResponseError extends UpdateRemoteFileResponseErrorType {
}
export {};
//# sourceMappingURL=remote.d.ts.map