/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PreferredAuthOption } from "../common";
import { UserIdOption } from "../common";
import { DefsOkTrueAsResponse } from "../definitions/DefsOkTrueAsResponse";
import { DefsOkFalseAsResponse } from "../definitions/DefsOkFalseAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { DefsUserIdAsResponse } from "../definitions/DefsUserIdAsResponse";
import { ObjsFileAsResponse } from "../definitions/ObjsFileAsResponse";
import { DefsChannelAsResponse } from "../definitions/DefsChannelAsResponse";
import { ObjsMessageAsResponse } from "../definitions/ObjsMessageAsResponse";
export interface RemovePinRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * Channel where the item is pinned to.
         */
        channel: string;
        /**
         * Timestamp of the message to un-pin.
         */
        timestamp?: string;
    };
}
declare type RemovePinResponseOKType = {
    ok: DefsOkTrueAsResponse;
};
export interface RemovePinResponseOK extends RemovePinResponseOKType {
}
declare type RemovePinResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "bad_timestamp" | "file_not_found" | "file_comment_not_found" | "message_not_found" | "no_item_specified" | "not_pinned" | "permission_denied" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_typ" | "missing_post_typ" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeou" | "upgrade_required";
    ok: DefsOkFalseAsResponse;
};
export interface RemovePinResponseError extends RemovePinResponseErrorType {
}
export interface GetPinsRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * Channel to get pinned items for.
     */
    channel: string;
}
export declare type GetPinsResponseOK = {
    items: Array<{
        created?: number;
        created_by?: DefsUserIdAsResponse;
        file?: ObjsFileAsResponse;
        type?: "file";
    } & {
        channel?: DefsChannelAsResponse;
        created?: number;
        created_by?: DefsUserIdAsResponse;
        message?: ObjsMessageAsResponse;
        type?: "message";
    }>;
    ok: DefsOkTrueAsResponse;
} & {
    count: number;
    ok: DefsOkTrueAsResponse;
};
declare type GetPinsResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "channel_not_found" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
    ok: DefsOkFalseAsResponse;
};
export interface GetPinsResponseError extends GetPinsResponseErrorType {
}
export interface AddPinRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * Channel to pin the item in.
         */
        channel: string;
        /**
         * Timestamp of the message to pin.
         */
        timestamp?: string;
    };
}
declare type AddPinResponseOKType = {
    ok: DefsOkTrueAsResponse;
};
export interface AddPinResponseOK extends AddPinResponseOKType {
}
declare type AddPinResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "bad_timestamp" | "message_not_found" | "channel_not_found" | "no_item_specified" | "already_pinned" | "permission_denied" | "file_not_shared" | "not_pinnable" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
    ok: DefsOkFalseAsResponse;
};
export interface AddPinResponseError extends AddPinResponseErrorType {
}
export {};
//# sourceMappingURL=pins.d.ts.map