/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PreferredAuthOption } from "../common";
import { UserIdOption } from "../common";
import { DefsOkTrueAsResponse } from "../definitions/DefsOkTrueAsResponse";
import { DefsOkFalseAsResponse } from "../definitions/DefsOkFalseAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ObjsFileAsResponse } from "../definitions/ObjsFileAsResponse";
import { ObjsMessageAsResponse } from "../definitions/ObjsMessageAsResponse";
import { DefsChannelAsResponse } from "../definitions/DefsChannelAsResponse";
import { ObjsCommentAsResponse } from "../definitions/ObjsCommentAsResponse";
import { ObjsPagingAsResponse } from "../definitions/ObjsPagingAsResponse";
import { ObjsResponseMetadataAsResponse } from "../definitions/ObjsResponseMetadataAsResponse";
export interface AddReactionRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * Channel where the message to add reaction to was posted.
         */
        channel: string;
        /**
         * Reaction (emoji) name.
         */
        name: string;
        /**
         * Timestamp of the message to add reaction to.
         */
        timestamp: string;
    };
}
declare type AddReactionResponseOKType = {
    ok: DefsOkTrueAsResponse;
};
export interface AddReactionResponseOK extends AddReactionResponseOKType {
}
declare type AddReactionResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "bad_timestamp" | "message_not_found" | "no_item_specified" | "invalid_name" | "already_reacted" | "too_many_emoji" | "too_many_reactions" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
    ok: DefsOkFalseAsResponse;
};
export interface AddReactionResponseError extends AddReactionResponseErrorType {
}
export interface GetReactionRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * Channel where the message to get reactions for was posted.
     */
    channel?: string;
    /**
     * File to get reactions for.
     */
    file?: string;
    /**
     * File comment to get reactions for.
     */
    file_comment?: string;
    /**
     * If true always return the complete reaction list.
     */
    full?: boolean;
    /**
     * Timestamp of the message to get reactions for.
     */
    timestamp?: string;
}
export declare type GetReactionResponseOK = {
    ok: DefsOkTrueAsResponse;
    type: "file";
    file: ObjsFileAsResponse;
} | {
    ok: DefsOkTrueAsResponse;
    type: "message";
    message: ObjsMessageAsResponse;
    channel: DefsChannelAsResponse;
} | {
    ok: DefsOkTrueAsResponse;
    comment: ObjsCommentAsResponse;
    file: ObjsFileAsResponse;
    type: "file_comment";
};
export interface GetReactionResponseError {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "bad_timestamp" | "file_not_found" | "file_comment_not_found" | "message_not_found" | "no_item_specified" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
    ok: DefsOkFalseAsResponse;
}
export interface GetReactionsRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * Number of items to return per page.
     */
    count?: string;
    /**
     * If true always return the complete reaction list.
     */
    full?: boolean;
    /**
     * Parameter for pagination. Set `cursor` equal to the `next_cursor` attribute returned by the previous request's `response_metadata`. This parameter is optional, but pagination is mandatory: the default value simply fetches the first "page" of the collection. See [pagination](/docs/pagination) for more details.
     */
    cursor?: string;
    /**
     * The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the list hasn't been reached.
     */
    limit?: number;
    /**
     * Show reactions made by this user. Defaults to the authed user.
     */
    user?: string;
    /**
     * Page number of results to return.
     */
    page?: string;
}
export interface GetReactionsResponseOK {
    items: Array<any>;
    ok: DefsOkTrueAsResponse;
    paging?: ObjsPagingAsResponse;
    response_metadata?: ObjsResponseMetadataAsResponse;
}
export interface GetReactionsResponseError {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "bad_timestamp" | "file_not_found" | "file_comment_not_found" | "message_not_found" | "no_item_specified" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
    ok: DefsOkFalseAsResponse;
}
export interface RemoveReactionRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * Reaction (emoji) name.
         */
        name: string;
        /**
         * File to remove reaction from.
         */
        file?: string;
        /**
         * File comment to remove reaction from.
         */
        file_comment?: string;
        /**
         * Channel where the message to remove reaction from was posted.
         */
        channel?: string;
        /**
         * Timestamp of the message to remove reaction from.
         */
        timestamp?: string;
    };
}
declare type RemoveReactionResponseOKType = {
    ok: DefsOkTrueAsResponse;
};
export interface RemoveReactionResponseOK extends RemoveReactionResponseOKType {
}
declare type RemoveReactionResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "bad_timestamp" | "file_not_found" | "file_comment_not_found" | "message_not_found" | "no_item_specified" | "invalid_name" | "no_reaction" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface RemoveReactionResponseError extends RemoveReactionResponseErrorType {
}
export {};
//# sourceMappingURL=reaction.d.ts.map