/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { UserIdOption } from "../common";
import { DefsOkTrueAsResponse } from "../definitions/DefsOkTrueAsResponse";
import { ObjsReminderAsResponse } from "../definitions/ObjsReminderAsResponse";
import { DefsOkFalseAsResponse } from "../definitions/DefsOkFalseAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
export interface GetRemindersRequest extends HeadersOption, ErrorStrategyOption, UserIdOption {
    /**
     * Encoded team id, required if org token is used
     */
    team_id?: string;
}
declare type GetRemindersResponseOKType = {
    ok: DefsOkTrueAsResponse;
    reminders: Array<ObjsReminderAsResponse>;
};
export interface GetRemindersResponseOK extends GetRemindersResponseOKType {
}
declare type GetRemindersResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface GetRemindersResponseError extends GetRemindersResponseErrorType {
}
export interface GetReminderInfoRequest extends HeadersOption, ErrorStrategyOption, UserIdOption {
    /**
     * The ID of the reminder
     */
    reminder: string;
    /**
     * Encoded team id, required if org token is used
     */
    team_id?: string;
}
declare type GetReminderInfoResponseOKType = {
    ok: DefsOkTrueAsResponse;
    reminder: ObjsReminderAsResponse;
};
export interface GetReminderInfoResponseOK extends GetReminderInfoResponseOKType {
}
declare type GetReminderInfoResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "not_found" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface GetReminderInfoResponseError extends GetReminderInfoResponseErrorType {
}
export interface DeleteReminderRequest extends HeadersOption, ErrorStrategyOption, UserIdOption {
    body: {
        /**
         * The ID of the reminder
         */
        reminder: string;
        /**
         * Encoded team id, required if org token is used
         */
        team_id?: string;
    };
}
declare type DeleteReminderResponseOKType = {
    ok: DefsOkTrueAsResponse;
};
export interface DeleteReminderResponseOK extends DeleteReminderResponseOKType {
}
declare type DeleteReminderResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "not_found" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface DeleteReminderResponseError extends DeleteReminderResponseErrorType {
}
export interface CompleteReminderRequest extends HeadersOption, ErrorStrategyOption, UserIdOption {
    body: {
        /**
         * The ID of the reminder to be marked as complete
         */
        reminder: string;
        /**
         * Encoded team id, required if org token is used
         */
        team_id?: string;
    };
}
declare type CompleteReminderResponseOKType = {
    ok: DefsOkTrueAsResponse;
};
export interface CompleteReminderResponseOK extends CompleteReminderResponseOKType {
}
declare type CompleteReminderResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "not_found" | "cannot_complete_recurring" | "cannot_complete_others" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface CompleteReminderResponseError extends CompleteReminderResponseErrorType {
}
export interface AddReminderRequest extends HeadersOption, ErrorStrategyOption, UserIdOption {
    body: {
        /**
         * The content of the reminder
         */
        text: string;
        /**
         * When this reminder should happen: the Unix timestamp (up to five years from now), the number of seconds until the reminder (if within 24 hours), or a natural language description (Ex. "in 15 minutes," or "every Thursday")
         */
        time: string;
        /**
         * The user who will receive the reminder. If no user is specified, the reminder will go to user who created it.
         */
        user?: string;
        /**
         * Encoded team id, required if org token is used
         */
        team_id?: string;
        /**
         * Specify the repeating behavior of a reminder. Available options: daily, weekly, monthly, or yearly. If weekly, may further specify the days of the week.
         */
        recurrence?: any;
    };
}
declare type AddReminderResponseOKType = {
    ok: DefsOkTrueAsResponse;
    reminder: ObjsReminderAsResponse;
};
export interface AddReminderResponseOK extends AddReminderResponseOKType {
}
declare type AddReminderResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "cannot_parse" | "user_not_found" | "cannot_add_bot" | "cannot_add_slackbot" | "cannot_add_others" | "cannot_add_others_recurring" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface AddReminderResponseError extends AddReminderResponseErrorType {
}
export {};
//# sourceMappingURL=reminders.d.ts.map