/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { UserIdOption } from "../common";
import { DefsOkTrueAsResponse } from "../definitions/DefsOkTrueAsResponse";
import { ObjsPagingAsResponse } from "../definitions/ObjsPagingAsResponse";
import { ObjsMessageAsResponse } from "../definitions/ObjsMessageAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
export interface SearchMessagesRequest extends HeadersOption, ErrorStrategyOption, UserIdOption {
    /**
     * Change sort direction to ascending (`asc`) or descending (`desc`).
     */
    sort_dir?: "asc" | "desc";
    /**
     * Search query.
     */
    query: string;
    /**
     * Return matches sorted by either `score` or `timestamp`.
     */
    sort?: "score" | "timestamp";
    /**
     * Number of items to return per page.
     */
    count?: number;
    /**
     * Pass a value of `true` to enable query highlight markers (see below).
     */
    highlight?: boolean;
    /**
     * Page number of results to return.
     */
    page?: number;
}
declare type SearchMessagesResponseOKType = {
    ok: DefsOkTrueAsResponse;
    query: string;
    messages?: {
        total?: number;
        pagination?: {
            total_count?: number;
            page?: number;
            per_page?: number;
            page_count?: number;
            first?: number;
            last?: number;
        };
        paging?: ObjsPagingAsResponse;
        matches?: Array<ObjsMessageAsResponse>;
    };
};
export interface SearchMessagesResponseOK extends SearchMessagesResponseOKType {
}
declare type SearchMessagesResponseErrorType = {
    error: "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkTrueAsResponse;
    response_metadata?: {
        messages?: Array<string>;
    };
};
export interface SearchMessagesResponseError extends SearchMessagesResponseErrorType {
}
export {};
//# sourceMappingURL=search.d.ts.map