/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { UserIdOption } from "../common";
import { DefsUserIdAsResponse } from "../definitions/DefsUserIdAsResponse";
import { DefsOkTrueAsResponse } from "../definitions/DefsOkTrueAsResponse";
import { ObjsPagingAsResponse } from "../definitions/ObjsPagingAsResponse";
import { DefsOkFalseAsResponse } from "../definitions/DefsOkFalseAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { PreferredAuthOption } from "../common";
import { ObjsTeamAsResponse } from "../definitions/ObjsTeamAsResponse";
import { DefsAppIdAsResponse } from "../definitions/DefsAppIdAsResponse";
import { DefsChannelAsResponse } from "../definitions/DefsChannelAsResponse";
export interface GetTeamAccessLogsRequest extends HeadersOption, ErrorStrategyOption, UserIdOption {
    /**
     * Number of items to return per page.
     */
    count?: number;
    /**
     * Page number of results to return.
     */
    page?: number;
    /**
     * End of time range of logs to include in results (inclusive).
     */
    before?: number;
}
declare type GetTeamAccessLogsResponseOKType = {
    logins: Array<{
        count: number;
        country: string | null;
        date_first: number;
        date_last: number;
        ip: string | null;
        isp: string | null;
        region: string | null;
        user_agent: string;
        user_id: DefsUserIdAsResponse;
        username: string;
    }>;
    ok: DefsOkTrueAsResponse;
    paging: ObjsPagingAsResponse;
};
export interface GetTeamAccessLogsResponseOK extends GetTeamAccessLogsResponseOKType {
}
declare type GetTeamAccessLogsResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "paid_only" | "over_pagination_limit" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface GetTeamAccessLogsResponseError extends GetTeamAccessLogsResponseErrorType {
}
export interface GetTeamBillableInfoRequest extends HeadersOption, ErrorStrategyOption, UserIdOption {
    /**
     * A user to retrieve the billable information for. Defaults to all users.
     */
    user?: string;
}
declare type GetTeamBillableInfoResponseOKType = {
    billable_info: {
        [x: string]: {
            billing_active: boolean;
        };
    };
    ok: DefsOkTrueAsResponse;
};
export interface GetTeamBillableInfoResponseOK extends GetTeamBillableInfoResponseOKType {
}
declare type GetTeamBillableInfoResponseErrorType = {
    error: "user_not_found" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface GetTeamBillableInfoResponseError extends GetTeamBillableInfoResponseErrorType {
}
export interface GetTeamInfoRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * Team to get info on, if omitted, will return information about the current team. Will only return team that the authenticated token is allowed to see through external shared channels
     */
    team?: string;
}
declare type GetTeamInfoResponseOKType = {
    ok: DefsOkTrueAsResponse;
    team: ObjsTeamAsResponse;
};
export interface GetTeamInfoResponseOK extends GetTeamInfoResponseOKType {
}
declare type GetTeamInfoResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface GetTeamInfoResponseError extends GetTeamInfoResponseErrorType {
}
export interface GetTeamIntegrationLogsRequest extends HeadersOption, ErrorStrategyOption, UserIdOption {
    /**
     * Filter logs to this Slack app. Defaults to all logs.
     */
    app_id?: string;
    /**
     * Filter logs with this change type. Defaults to all logs.
     */
    change_type?: string;
    count?: string;
    page?: string;
    /**
     * Filter logs to this service. Defaults to all logs.
     */
    service_id?: string;
    /**
     * Filter logs generated by this user’s actions. Defaults to all logs.
     */
    user?: string;
}
declare type GetTeamIntegrationLogsResponseOKType = {
    logs: Array<{
        admin_app_id?: DefsAppIdAsResponse;
        app_id: DefsAppIdAsResponse;
        app_type: string;
        change_type: string;
        channel?: DefsChannelAsResponse;
        date: string;
        scope: string;
        service_id?: string;
        service_type?: string;
        user_id: DefsUserIdAsResponse;
        user_name: string;
    }>;
    ok: DefsOkTrueAsResponse;
    paging: ObjsPagingAsResponse;
};
export interface GetTeamIntegrationLogsResponseOK extends GetTeamIntegrationLogsResponseOKType {
}
declare type GetTeamIntegrationLogsResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface GetTeamIntegrationLogsResponseError extends GetTeamIntegrationLogsResponseErrorType {
}
export {};
//# sourceMappingURL=team.d.ts.map