/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PreferredAuthOption } from "../common";
import { UserIdOption } from "../common";
import { DefsOkTrueAsResponse } from "../definitions/DefsOkTrueAsResponse";
import { ObjsUserAsResponse } from "../definitions/ObjsUserAsResponse";
import { DefsOkFalseAsResponse } from "../definitions/DefsOkFalseAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ObjsResponseMetadataAsResponse } from "../definitions/ObjsResponseMetadataAsResponse";
import { DefsTeamAsResponse } from "../definitions/DefsTeamAsResponse";
import { DefsUserIdAsResponse } from "../definitions/DefsUserIdAsResponse";
import { ObjsConversationAsResponse } from "../definitions/ObjsConversationAsResponse";
export interface GetUserByEmailRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * An email address belonging to a user in the workspace
     */
    email: string;
}
declare type GetUserByEmailResponseOKType = {
    ok: DefsOkTrueAsResponse;
    user: ObjsUserAsResponse;
    [x: string]: any;
};
export interface GetUserByEmailResponseOK extends GetUserByEmailResponseOKType {
}
declare type GetUserByEmailResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "users_not_found" | "enterprise_is_restricted" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface GetUserByEmailResponseError extends GetUserByEmailResponseErrorType {
}
export interface GetUsersRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the users list hasn't been reached. Providing no `limit` value will result in Slack attempting to deliver you the entire result set. If the collection is too large you may experience `limit_required` or HTTP 500 errors.
     */
    limit?: number;
    /**
     * Paginate through collections of data by setting the `cursor` parameter to a `next_cursor` attribute returned by a previous request's `response_metadata`. Default value fetches the first "page" of the collection. See [pagination](/docs/pagination) for more detail.
     */
    cursor?: string;
    /**
     * Set this to `true` to receive the locale for users. Defaults to `false`
     */
    include_locale?: boolean;
    /**
     * Encoded team id to list users in, required if org token is used
     */
    team_id?: string;
}
declare type GetUsersResponseOKType = {
    cache_ts: number;
    members: Array<ObjsUserAsResponse>;
    ok: DefsOkTrueAsResponse;
    response_metadata?: ObjsResponseMetadataAsResponse;
};
export interface GetUsersResponseOK extends GetUsersResponseOKType {
}
declare type GetUsersResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "limit_required" | "invalid_cursor" | "not_authed" | "invalid_auth" | "account_inactive" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface GetUsersResponseError extends GetUsersResponseErrorType {
}
export interface GetUserInfoRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * Set this to `true` to receive the locale for this user. Defaults to `false`
     */
    include_locale?: boolean;
    /**
     * User to get info on
     */
    user: string;
}
declare type GetUserInfoResponseOKType = {
    ok: DefsOkTrueAsResponse;
    user: ObjsUserAsResponse;
    [x: string]: any;
};
export interface GetUserInfoResponseOK extends GetUserInfoResponseOKType {
}
declare type GetUserInfoResponseErrorType = {
    callstack?: string;
    error: "user_not_found" | "user_not_visible" | "not_authed" | "invalid_auth" | "account_inactive" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required";
    ok: DefsOkFalseAsResponse;
};
export interface GetUserInfoResponseError extends GetUserInfoResponseErrorType {
}
export interface GetUserIdentityRequest extends HeadersOption, ErrorStrategyOption, UserIdOption {
}
export declare type GetUserIdentityResponseOK = {
    ok: DefsOkTrueAsResponse;
    team: {
        id: DefsTeamAsResponse;
    };
    user: {
        id: DefsUserIdAsResponse;
        name: string;
    };
} & {
    ok: DefsOkTrueAsResponse;
    team: {
        id: DefsTeamAsResponse;
    };
    user: {
        email: string;
        id: DefsUserIdAsResponse;
        name: string;
    };
} & {
    ok: DefsOkTrueAsResponse;
    team: {
        id: DefsTeamAsResponse;
    };
    user: {
        id: DefsUserIdAsResponse;
        image_192: string;
        image_24: string;
        image_32: string;
        image_48: string;
        image_512: string;
        image_72: string;
        name: string;
    };
} & {
    ok: DefsOkTrueAsResponse;
    team: {
        domain: string;
        id: DefsTeamAsResponse;
        image_102: string;
        image_132: string;
        image_230: string;
        image_34: string;
        image_44: string;
        image_68: string;
        image_88: string;
        image_default: boolean;
        name: string;
    };
    user: {
        id: DefsUserIdAsResponse;
        name: string;
    };
};
declare type GetUserIdentityResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface GetUserIdentityResponseError extends GetUserIdentityResponseErrorType {
}
export interface GetUserConversationsRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * Browse conversations by a specific user ID's membership. Non-public channels are restricted to those where the calling user shares membership.
     */
    user?: string;
    /**
     * Mix and match channel types by providing a comma-separated list of any combination of `public_channel`, `private_channel`, `mpim`, `im`
     */
    types?: string;
    /**
     * Set to `true` to exclude archived channels from the list
     */
    exclude_archived?: boolean;
    /**
     * The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the list hasn't been reached. Must be an integer no larger than 1000.
     */
    limit?: number;
    /**
     * Paginate through collections of data by setting the `cursor` parameter to a `next_cursor` attribute returned by a previous request's `response_metadata`. Default value fetches the first "page" of the collection. See [pagination](/docs/pagination) for more detail.
     */
    cursor?: string;
    /**
     * Encoded team id to list conversations in, required if org token is used
     */
    team_id?: string;
}
declare type GetUserConversationsResponseOKType = {
    channels: Array<ObjsConversationAsResponse>;
    ok: DefsOkTrueAsResponse;
    response_metadata?: {
        next_cursor: string;
    };
    [x: string]: any;
};
export interface GetUserConversationsResponseOK extends GetUserConversationsResponseOKType {
}
declare type GetUserConversationsResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "method_not_supported_for_channel_type" | "missing_scope" | "invalid_types" | "invalid_cursor" | "invalid_limit" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface GetUserConversationsResponseError extends GetUserConversationsResponseErrorType {
}
export interface GetUserPresenceRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * User to get presence info on. Defaults to the authed user.
     */
    user?: string;
}
declare type GetUserPresenceResponseOKType = {
    auto_away?: boolean;
    connection_count?: number;
    last_activity?: number;
    manual_away?: boolean;
    ok: DefsOkTrueAsResponse;
    online?: boolean;
    presence: string;
    [x: string]: any;
};
export interface GetUserPresenceResponseOK extends GetUserPresenceResponseOKType {
}
declare type GetUserPresenceResponseErrorType = {
    error: string;
    ok: DefsOkFalseAsResponse;
    [x: string]: any;
};
export interface GetUserPresenceResponseError extends GetUserPresenceResponseErrorType {
}
export interface SetUserPresenceRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * Either `auto` or `away`
         */
        presence: string;
    };
}
declare type SetUserPresenceResponseOKType = {
    ok: DefsOkTrueAsResponse;
};
export interface SetUserPresenceResponseOK extends SetUserPresenceResponseOKType {
}
declare type SetUserPresenceResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "invalid_presence" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface SetUserPresenceResponseError extends SetUserPresenceResponseErrorType {
}
export {};
//# sourceMappingURL=user.d.ts.map