/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { UserIdOption } from "../../common";
import { DefsOkTrueAsResponse } from "../../definitions/DefsOkTrueAsResponse";
import { ObjsUserProfileAsResponse } from "../../definitions/ObjsUserProfileAsResponse";
import { DefsOkFalseAsResponse } from "../../definitions/DefsOkFalseAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { PreferredAuthOption } from "../../common";
export interface SetUserProfileRequest extends HeadersOption, ErrorStrategyOption, UserIdOption {
    body: {
        /**
         * Name of a single key to set. Usable only if `profile` is not passed.
         */
        name?: string;
        /**
         * Collection of key:value pairs presented as a URL-encoded JSON hash. At most 50 fields may be set. Each field name is limited to 255 characters.
         */
        profile?: string;
        /**
         * ID of user to change. This argument may only be specified by team admins on paid teams.
         */
        user?: string;
        /**
         * Value to set a single key to. Usable only if `profile` is not passed.
         */
        value?: string;
    };
}
declare type SetUserProfileResponseOKType = {
    email_pending?: string;
    ok: DefsOkTrueAsResponse;
    profile: ObjsUserProfileAsResponse;
    username: string;
};
export interface SetUserProfileResponseOK extends SetUserProfileResponseOKType {
}
declare type SetUserProfileResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "reserved_name" | "invalid_profile" | "profile_set_failed" | "not_admin" | "not_app_admin" | "cannot_update_admin_user" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface SetUserProfileResponseError extends SetUserProfileResponseErrorType {
}
export interface GetUserProfileRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * Include labels for each ID in custom profile fields
     */
    include_labels?: boolean;
    /**
     * User to retrieve profile info for
     */
    user?: string;
}
declare type GetUserProfileResponseOKType = {
    ok: DefsOkTrueAsResponse;
    profile: ObjsUserProfileAsResponse;
};
export interface GetUserProfileResponseOK extends GetUserProfileResponseOKType {
}
declare type GetUserProfileResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "user_not_found" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface GetUserProfileResponseError extends GetUserProfileResponseErrorType {
}
export {};
//# sourceMappingURL=profile.d.ts.map