/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PreferredAuthOption } from "../common";
import { UserIdOption } from "../common";
import { DefsOkTrueAsResponse } from "../definitions/DefsOkTrueAsResponse";
import { ObjsSubteamAsResponse } from "../definitions/ObjsSubteamAsResponse";
import { DefsOkFalseAsResponse } from "../definitions/DefsOkFalseAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
export interface CreateUserGroupRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * A comma separated string of encoded channel IDs for which the User Group uses as a default.
         */
        channels?: string;
        /**
         * A short description of the User Group.
         */
        description?: string;
        /**
         * A mention handle. Must be unique among channels, users and User Groups.
         */
        handle?: string;
        /**
         * Include the number of users in each User Group.
         */
        include_count?: boolean;
        /**
         * A name for the User Group. Must be unique among User Groups.
         */
        name: string;
    };
}
declare type CreateUserGroupResponseOKType = {
    ok: DefsOkTrueAsResponse;
    usergroup: ObjsSubteamAsResponse;
};
export interface CreateUserGroupResponseOK extends CreateUserGroupResponseOKType {
}
declare type CreateUserGroupResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "permission_denied" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "user_is_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface CreateUserGroupResponseError extends CreateUserGroupResponseErrorType {
}
export interface DisableUserGroupRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * Include the number of users in the User Group.
         */
        include_count?: boolean;
        /**
         * The encoded ID of the User Group to disable.
         */
        usergroup: string;
    };
}
declare type DisableUserGroupResponseOKType = {
    ok: DefsOkTrueAsResponse;
    usergroup: ObjsSubteamAsResponse;
};
export interface DisableUserGroupResponseOK extends DisableUserGroupResponseOKType {
}
declare type DisableUserGroupResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "permission_denied" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "user_is_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_required" | "fatal_error";
    ok: DefsOkFalseAsResponse;
};
export interface DisableUserGroupResponseError extends DisableUserGroupResponseErrorType {
}
export interface EnableUserGroupRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * Include the number of users in the User Group.
         */
        include_count?: boolean;
        /**
         * The encoded ID of the User Group to enable.
         */
        usergroup: string;
    };
}
declare type EnableUserGroupResponseOKType = {
    ok: DefsOkTrueAsResponse;
    usergroup: ObjsSubteamAsResponse;
};
export interface EnableUserGroupResponseOK extends EnableUserGroupResponseOKType {
}
declare type EnableUserGroupResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "user_is_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_require" | "fatal_error" | "missing_charset" | "superfluous_charset";
    ok: DefsOkFalseAsResponse;
};
export interface EnableUserGroupResponseError extends EnableUserGroupResponseErrorType {
}
export interface GetUserGroupsRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * Include the list of users for each User Group.
     */
    include_users?: boolean;
    /**
     * Include the number of users in each User Group.
     */
    include_count?: boolean;
    /**
     * Include disabled User Groups.
     */
    include_disabled?: boolean;
}
declare type GetUserGroupsResponseOKType = {
    ok: DefsOkTrueAsResponse;
    usergroups: Array<ObjsSubteamAsResponse>;
};
export interface GetUserGroupsResponseOK extends GetUserGroupsResponseOKType {
}
declare type GetUserGroupsResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "user_is_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_require" | "fatal_error" | "missing_charset" | "superfluous_charset";
    ok: DefsOkFalseAsResponse;
};
export interface GetUserGroupsResponseError extends GetUserGroupsResponseErrorType {
}
export interface UpdateUserGroupRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    body: {
        /**
         * A mention handle. Must be unique among channels, users and User Groups.
         */
        handle?: string;
        /**
         * A short description of the User Group.
         */
        description?: string;
        /**
         * A comma separated string of encoded channel IDs for which the User Group uses as a default.
         */
        channels?: string;
        /**
         * Include the number of users in the User Group.
         */
        include_count?: boolean;
        /**
         * The encoded ID of the User Group to update.
         */
        usergroup: string;
        /**
         * A name for the User Group. Must be unique among User Groups.
         */
        name?: string;
    };
}
declare type UpdateUserGroupResponseOKType = {
    ok: DefsOkTrueAsResponse;
    usergroup: ObjsSubteamAsResponse;
};
export interface UpdateUserGroupResponseOK extends UpdateUserGroupResponseOKType {
}
declare type UpdateUserGroupResponseErrorType = {
    /**
     * Note: PHP callstack is only visible in dev/qa
     */
    callstack?: string;
    error: "permission_denied" | "not_authed" | "invalid_auth" | "account_inactive" | "token_revoked" | "no_permission" | "org_login_required" | "user_is_bot" | "user_is_restricted" | "invalid_arg_name" | "invalid_array_arg" | "invalid_charset" | "invalid_form_data" | "invalid_post_type" | "missing_post_type" | "team_added_to_org" | "invalid_json" | "json_not_object" | "request_timeout" | "upgrade_require" | "fatal_error" | "missing_charset" | "superfluous_charset";
    ok: DefsOkFalseAsResponse;
};
export interface UpdateUserGroupResponseError extends UpdateUserGroupResponseErrorType {
}
export {};
//# sourceMappingURL=userGroup.d.ts.map