/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PreferredAuthOption } from "../common";
import { UserIdOption } from "../common";
import { DefsOkTrueAsResponse } from "../definitions/DefsOkTrueAsResponse";
import { DefsOkFalseAsResponse } from "../definitions/DefsOkFalseAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ObjsViewResponse } from "../definitions/ObjsView";
export interface UpdateViewRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * A [view payload](/reference/surfaces/views). This must be a JSON-encoded string.
     */
    view: string;
    /**
     * A unique identifier of the view set by the developer. Must be unique for all views on a team. Max length of 255 characters. Either view_id or external_id is required.
     */
    external_id?: string;
    /**
     * A string that represents view state to protect against possible race conditions.
     */
    hash?: string;
    /**
     * A unique identifier of the view to be updated. Either view_id or external_id is required.
     */
    view_id?: string;
}
export interface UpdateViewResponseOK {
    ok: DefsOkTrueAsResponse;
    view: ObjsViewResponse;
}
export interface UpdateViewResponseError {
    ok: DefsOkFalseAsResponse;
    [x: string]: any;
}
export interface PushViewRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * Exchange a trigger to post to the user.
     */
    trigger_id: string;
    /**
     * A [view payload](/reference/surfaces/views). This must be a JSON-encoded string.
     */
    view: string;
}
export interface PushViewResponseOK {
    ok: DefsOkTrueAsResponse;
    view: ObjsViewResponse;
}
export interface PushViewResponseError {
    ok: DefsOkFalseAsResponse;
    [x: string]: any;
}
export interface PublishViewRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * id of the user you want publish a view to.
     */
    user_id: string;
    /**
     * A [view payload](/reference/surfaces/views). This must be a JSON-encoded string.
     */
    view: string;
    /**
     * A string that represents view state to protect against possible race conditions.
     */
    hash?: string;
}
export interface PublishViewResponseOK {
    ok: DefsOkTrueAsResponse;
    view: ObjsViewResponse;
}
export interface PublishViewResponseError {
    ok: DefsOkFalseAsResponse;
    [x: string]: any;
}
export interface OpenViewRequest extends HeadersOption, ErrorStrategyOption, PreferredAuthOption, UserIdOption {
    /**
     * Exchange a trigger to post to the user.
     */
    trigger_id: string;
    /**
     * A [view payload](/reference/surfaces/views). This must be a JSON-encoded string.
     */
    view: string;
}
export interface OpenViewResponseOK {
    ok: DefsOkTrueAsResponse;
    view: ObjsViewResponse;
}
export interface OpenViewResponseError {
    ok: DefsOkFalseAsResponse;
    [x: string]: any;
}
//# sourceMappingURL=view.d.ts.map